@@ -30,12 +30,13 @@ public slots:
     void init();
     void cleanup();
 
+    void save();
+
 private slots:
     void AutoSaver_data();
     void AutoSaver();
     void changeOccurred_data();
     void changeOccurred();
-
     void deleted();
 };
 
@@ -103,6 +104,11 @@ void tst_AutoSaver::AutoSaver()
 {
     SubAutoSaver save(this);
     save.changeOccurred();
+    save.saveIfNeccessary();
+}
+
+void tst_AutoSaver::save()
+{
 }
 
 typedef QList<int> IntList;
