@@ -62,11 +62,11 @@
 
 #include "browserapplication.h"
 
-#include "bookmarks.h"
+#include "bookmarksmanager.h"
 #include "browsermainwindow.h"
 #include "cookiejar.h"
 #include "downloadmanager.h"
-#include "history.h"
+#include "historymanager.h"
 #include "languagemanager.h"
 #include "networkaccessmanager.h"
 #include "tabwidget.h"
@@ -91,27 +91,29 @@ LanguageManager *BrowserApplication::s_languageManager = 0;
 
 BrowserApplication::BrowserApplication(int &argc, char **argv)
     : SingleApplication(argc, argv)
-    , quiting(false)
+    , quitting(false)
 {
     QCoreApplication::setOrganizationDomain(QLatin1String("arora-browser.org"));
     QCoreApplication::setApplicationName(QLatin1String("Arora"));
-    QString version = QLatin1String("0.5");
-    if (QLatin1String(GITCHANGENUMBER) != QLatin1String("0"))
-        version += QString(tr(" (Change: %1 %2)"))
+    QString version = QLatin1String("0.8.0");
+    QString gitVersion = QLatin1String(GITCHANGENUMBER);
+    if (gitVersion != QLatin1String("0")
+        && !gitVersion.isEmpty())
+        version += QString(QLatin1String(" (git: %1 %2)"))
                     .arg(QLatin1String(GITCHANGENUMBER))
                     .arg(QLatin1String(GITVERSION));
 
     QCoreApplication::setApplicationVersion(version);
 #ifndef AUTOTESTS
     QStringList args = QCoreApplication::arguments();
-    QString message = (args.count() > 1) ? args.last() : QString();
+    QString message = (args.count() > 1) ? parseArgumentUrl(args.last()) : QString();
     if (sendMessage(message))
         return;
     // not sure what else to do...
     if (!startSingleServer())
         return;
-    connect(this, SIGNAL(messageRecieved(const QString &)),
-            this, SLOT(messageRecieved(const QString &)));
+    connect(this, SIGNAL(messageReceived(const QString &)),
+            this, SLOT(messageReceived(const QString &)));
 #endif
 
 #if defined(Q_WS_MAC)
@@ -136,15 +138,19 @@ BrowserApplication::BrowserApplication(int &argc, char **argv)
             this, SLOT(lastWindowClosed()));
 #endif
 
+    // setting this in the postLaunch actually takes a lot more time
+    // because the event has to be propagated to everyone.
+    setWindowIcon(QIcon(QLatin1String(":128x128/arora.png")));
+
 #ifndef AUTOTESTS
     QTimer::singleShot(0, this, SLOT(postLaunch()));
 #endif
-    LanguageManager();
+    languageManager();
 }
 
 BrowserApplication::~BrowserApplication()
 {
-    quiting = true;
+    quitting = true;
     delete s_downloadManager;
     qDeleteAll(m_mainWindows);
     delete s_networkAccessManager;
@@ -156,71 +162,89 @@ void BrowserApplication::lastWindowClosed()
 {
     clean();
     BrowserMainWindow *mw = new BrowserMainWindow;
-    mw->slotHome();
+    mw->goHome();
     m_mainWindows.prepend(mw);
 }
 #endif
 
 BrowserApplication *BrowserApplication::instance()
 {
-    return (static_cast<BrowserApplication *>(QCoreApplication::instance()));
+    return (static_cast<BrowserApplication*>(QCoreApplication::instance()));
 }
 
-void BrowserApplication::messageRecieved(const QString &message)
+void BrowserApplication::retranslate()
 {
-    QUrl url(message);
-    if (!url.isEmpty()) {
+    bookmarksManager()->retranslate();
+    networkAccessManager()->loadSettings();
+}
+
+// The only special property of an argument url is that the file's
+// can be local, they don't have to be absolute.
+QString BrowserApplication::parseArgumentUrl(const QString &string) const
+{
+    if (QFile::exists(string)) {
+        QFileInfo info(string);
+        return info.canonicalFilePath();
+    }
+    return string;
+}
+
+void BrowserApplication::messageReceived(const QString &message)
+{
+    if (!message.isEmpty()) {
         QSettings settings;
-        settings.beginGroup(QLatin1String("general"));
-        int openLinksIn = settings.value(QLatin1String("openLinksIn"), 0).toInt();
+        settings.beginGroup(QLatin1String("tabs"));
+        TabWidget::OpenUrlIn tab = TabWidget::OpenUrlIn(settings.value(QLatin1String("openLinksFromAppsIn"), TabWidget::NewSelectedTab).toInt());
         settings.endGroup();
-        if (openLinksIn == 1)
-            newMainWindow();
-        else
-            mainWindow()->tabWidget()->newTab();
-        openUrl(url);
+        mainWindow()->tabWidget()->loadString(message, tab);
     }
     mainWindow()->raise();
     mainWindow()->activateWindow();
 }
 
-#if defined(Q_WS_MAC)
-#include <qmessagebox.h>
 void BrowserApplication::quitBrowser()
 {
-    clean();
-    int tabCount = 0;
-    for (int i = 0; i < m_mainWindows.count(); ++i) {
-        tabCount += m_mainWindows.at(i)->tabWidget()->count();
-    }
+    if (s_downloadManager && !downloadManager()->allowQuit())
+        return;
 
-    if (tabCount > 1) {
-        int ret = QMessageBox::warning(mainWindow(), QString(),
-                           tr("There are %1 windows and %2 tabs open\n"
-                              "Do you want to quit anyway?").arg(m_mainWindows.count()).arg(tabCount),
-                           QMessageBox::Yes | QMessageBox::No,
-                           QMessageBox::No);
-        if (ret == QMessageBox::No)
-            return;
+    if (QSettings().value(QLatin1String("tabs/confirmClosingMultipleTabs"), true).toBool()) {
+        clean();
+        int tabCount = 0;
+        for (int i = 0; i < m_mainWindows.count(); ++i) {
+            tabCount += m_mainWindows.at(i)->tabWidget()->count();
+        }
+
+        if (tabCount > 1) {
+            int ret = QMessageBox::warning(mainWindow(), QString(),
+                               tr("There are %1 windows and %2 tabs open\n"
+                                  "Do you want to quit anyway?").arg(m_mainWindows.count()).arg(tabCount),
+                               QMessageBox::Yes | QMessageBox::No,
+                               QMessageBox::No);
+            if (ret == QMessageBox::No)
+                return;
+        }
     }
 
     saveSession();
     exit(0);
 }
-#endif
 
 /*!
     Any actions that can be delayed until the window is visible
  */
 void BrowserApplication::postLaunch()
 {
-    QString directory = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+    QDesktopServices::StandardLocation location;
+#if QT_VERSION >= 0x040500
+    location = QDesktopServices::CacheLocation;
+#else
+    location = QDesktopServices::DataLocation;
+#endif
+    QString directory = QDesktopServices::storageLocation(location);
     if (directory.isEmpty())
         directory = QDir::homePath() + QLatin1String("/.") + QCoreApplication::applicationName();
     QWebSettings::setIconDatabasePath(directory);
 
-    setWindowIcon(QIcon(QLatin1String(":128x128/arora.png")));
-
     loadSettings();
 
     // newMainWindow() needs to be called in main() for this to happen
@@ -231,21 +255,21 @@ void BrowserApplication::postLaunch()
         QStringList args = QCoreApplication::arguments();
 
         if (args.count() > 1) {
+            QString argumentUrl = parseArgumentUrl(args.last());
             switch (startup) {
             case 2: {
                 restoreLastSession();
-                WebView *webView = mainWindow()->tabWidget()->makeNewTab(true);
-                webView->loadUrl(args.last());
+                mainWindow()->tabWidget()->loadString(argumentUrl, TabWidget::NewSelectedTab);
                 break;
             }
             default:
-                mainWindow()->loadPage(args.last());
+                mainWindow()->tabWidget()->loadString(argumentUrl);
                 break;
             }
         } else {
             switch (startup) {
             case 0:
-                mainWindow()->slotHome();
+                mainWindow()->goHome();
                 break;
             case 1:
                 break;
@@ -281,6 +305,7 @@ void BrowserApplication::loadSettings()
     defaultSettings->setFontFamily(QWebSettings::FixedFont, fixedFont.family());
     defaultSettings->setFontSize(QWebSettings::DefaultFixedFontSize, fixedFont.pointSize());
 
+    defaultSettings->setAttribute(QWebSettings::JavascriptCanOpenWindows, !(settings.value(QLatin1String("blockPopupWindows"), true).toBool()));
     defaultSettings->setAttribute(QWebSettings::JavascriptEnabled, settings.value(QLatin1String("enableJavascript"), true).toBool());
     defaultSettings->setAttribute(QWebSettings::PluginsEnabled, settings.value(QLatin1String("enablePlugins"), true).toBool());
     defaultSettings->setAttribute(QWebSettings::AutoLoadImages, settings.value(QLatin1String("enableImages"), true).toBool());
@@ -301,6 +326,18 @@ QList<BrowserMainWindow*> BrowserApplication::mainWindows()
     return list;
 }
 
+bool BrowserApplication::allowToCloseWindow(BrowserMainWindow *window)
+{
+    Q_UNUSED(window)
+    if (mainWindows().count() > 1)
+        return true;
+
+    if (s_downloadManager)
+        return downloadManager()->allowQuit();
+
+    return true;
+}
+
 void BrowserApplication::clean()
 {
     // cleanup any deleted main windows first
@@ -313,7 +350,7 @@ static const qint32 BrowserApplicationMagic = 0xec;
 
 void BrowserApplication::saveSession()
 {
-    if (quiting)
+    if (quitting)
         return;
     QSettings settings;
     settings.beginGroup(QLatin1String("MainWindow"));
@@ -412,7 +449,8 @@ bool BrowserApplication::event(QEvent *event)
     }
     case QEvent::FileOpen:
         if (!m_mainWindows.isEmpty()) {
-            mainWindow()->loadPage(static_cast<QFileOpenEvent *>(event)->file());
+            QString file = static_cast<QFileOpenEvent*>(event)->file();
+            mainWindow()->tabWidget()->loadUrl(QUrl::fromLocalFile(file));
             return true;
         }
     default:
@@ -424,7 +462,9 @@ bool BrowserApplication::event(QEvent *event)
 
 void BrowserApplication::openUrl(const QUrl &url)
 {
-    mainWindow()->loadPage(url.toString());
+    setEventMouseButtons(mouseButtons());
+    setEventKeyboardModifiers(keyboardModifiers());
+    mainWindow()->tabWidget()->loadUrl(url);
 }
 
 BrowserMainWindow *BrowserApplication::newMainWindow()
@@ -432,7 +472,7 @@ BrowserMainWindow *BrowserApplication::newMainWindow()
     BrowserMainWindow *browser = new BrowserMainWindow();
     m_mainWindows.prepend(browser);
     connect(this, SIGNAL(privacyChanged(bool)),
-            browser, SLOT(slotPrivacyChanged(bool)));
+            browser, SLOT(privacyChanged(bool)));
     browser->show();
     return browser;
 }
@@ -440,9 +480,18 @@ BrowserMainWindow *BrowserApplication::newMainWindow()
 BrowserMainWindow *BrowserApplication::mainWindow()
 {
     clean();
-    if (m_mainWindows.isEmpty())
-        newMainWindow();
-    return m_mainWindows[0];
+
+    BrowserMainWindow *activeWindow = 0;
+
+    if (m_mainWindows.isEmpty()) {
+        activeWindow = newMainWindow();
+    } else {
+        activeWindow = qobject_cast<BrowserMainWindow*>(QApplication::activeWindow());
+        if (!activeWindow)
+            activeWindow = m_mainWindows[0];
+    }
+
+    return activeWindow;
 }
 
 CookieJar *BrowserApplication::cookieJar()
@@ -482,8 +531,11 @@ BookmarksManager *BrowserApplication::bookmarksManager()
 
 LanguageManager *BrowserApplication::languageManager()
 {
-    if (!s_languageManager)
+    if (!s_languageManager) {
         s_languageManager = new LanguageManager;
+        connect(s_languageManager, SIGNAL(languageChanged(const QString &)),
+                qApp, SLOT(retranslate()));
+    }
     return s_languageManager;
 }
 
@@ -495,7 +547,7 @@ QIcon BrowserApplication::icon(const QUrl &url)
     if (icon.isNull()) {
         QPixmap pixmap = QWebSettings::webGraphic(QWebSettings::DefaultFrameIconGraphic);
         if (pixmap.isNull()) {
-            pixmap = QPixmap(QLatin1String(":defaulticon.png"));
+            pixmap = QPixmap(QLatin1String(":graphics/defaulticon.png"));
             QWebSettings::setWebGraphic(QWebSettings::DefaultFrameIconGraphic, pixmap);
         }
         return pixmap;
@@ -512,6 +564,19 @@ QString BrowserApplication::dataDirectory()
 #endif
 }
 
+#if QT_VERSION >= 0x040500
+bool BrowserApplication::zoomTextOnly()
+{
+    return QWebSettings::globalSettings()->testAttribute(QWebSettings::ZoomTextOnly);
+}
+
+void BrowserApplication::setZoomTextOnly(bool textOnly)
+{
+    QWebSettings::globalSettings()->setAttribute(QWebSettings::ZoomTextOnly, textOnly);
+    emit instance()->zoomTextOnlyChanged(textOnly);
+}
+#endif
+
 bool BrowserApplication::isPrivate()
 {
     return QWebSettings::globalSettings()->testAttribute(QWebSettings::PrivateBrowsingEnabled);
@@ -522,3 +587,24 @@ void BrowserApplication::setPrivate(bool isPrivate)
     QWebSettings::globalSettings()->setAttribute(QWebSettings::PrivateBrowsingEnabled, isPrivate);
     emit instance()->privacyChanged(isPrivate);
 }
+
+Qt::MouseButtons BrowserApplication::eventMouseButtons() const
+{
+    return m_eventMouseButtons;
+}
+
+Qt::KeyboardModifiers BrowserApplication::eventKeyboardModifiers() const
+{
+    return m_eventKeyboardModifiers;
+}
+
+void BrowserApplication::setEventMouseButtons(Qt::MouseButtons buttons)
+{
+    m_eventMouseButtons = buttons;
+}
+
+void BrowserApplication::setEventKeyboardModifiers(Qt::KeyboardModifiers modifiers)
+{
+    m_eventKeyboardModifiers = modifiers;
+}
+
