@@ -74,12 +74,15 @@
 #include <qfileiconprovider.h>
 #include <qheaderview.h>
 #include <qmetaobject.h>
+#include <qmessagebox.h>
 #include <qsettings.h>
 
 #include <qdebug.h>
 
 #include <qwebsettings.h>
 
+//#define DOWNLOADMANAGER_DEBUG
+
 /*!
     DownloadItem is a widget that is displayed in the download manager list.
     It moves the data from the QNetworkReply into the QFile as well
@@ -121,6 +124,8 @@ void DownloadItem::init()
     m_startedSaving = false;
     m_finishedDownloading = false;
 
+    openButton->setEnabled(false);
+
     // attach to the m_reply
     m_url = m_reply->url();
     m_reply->setParent(this);
@@ -174,6 +179,18 @@ void DownloadItem::getFileName()
         }
     }
     m_output.setFileName(fileName);
+
+    // Check file path for saving.
+    QDir saveDirPath = QFileInfo(m_output.fileName()).dir();
+    if (!saveDirPath.exists()) {
+        if (!saveDirPath.mkpath(saveDirPath.absolutePath())) {
+            progressBar->setVisible(false);
+            stop();
+            downloadInfoLabel->setText(tr("Download directory (%1) couldn't be created.").arg(saveDirPath.absolutePath()));
+            return;
+        }
+    }
+
     fileNameLabel->setText(QFileInfo(m_output.fileName()).fileName());
     if (m_requestFileName)
         downloadReadyRead();
@@ -202,14 +219,21 @@ QString DownloadItem::saveFileName(const QString &directory) const
 
     if (baseName.isEmpty()) {
         baseName = QLatin1String("unnamed_download");
-        qDebug() << "DownloadManager:: downloading unknown file:" << m_url;
+
+#ifdef DOWNLOADMANAGER_DEBUG
+        qDebug() << "DownloadItem::" << __FUNCTION__ << "downloading unknown file:" << m_url;
+#endif
     }
-    QString name = directory + baseName + QLatin1Char('.') + endName;
+
+    if (!endName.isEmpty())
+        endName = QLatin1Char('.') + endName;
+
+    QString name = directory + baseName + endName;
     if (!m_requestFileName && QFile::exists(name)) {
         // already exists, don't overwrite
         int i = 1;
         do {
-            name = directory + baseName + QLatin1Char('-') + QString::number(i++) + QLatin1Char('.') + endName;
+            name = directory + baseName + QLatin1Char('-') + QString::number(i++) + endName;
         } while (QFile::exists(name));
     }
     return name;
@@ -229,7 +253,7 @@ void DownloadItem::stop()
 void DownloadItem::open()
 {
     QFileInfo info(m_output);
-    QUrl url = QUrl::fromLocalFile(info.absolutePath());
+    QUrl url = QUrl::fromLocalFile(info.absoluteFilePath());
     QDesktopServices::openUrl(url);
 }
 
@@ -284,7 +308,10 @@ void DownloadItem::downloadReadyRead()
 
 void DownloadItem::error(QNetworkReply::NetworkError)
 {
-    qDebug() << "DownloadItem::error" << m_reply->errorString() << m_url;
+#ifdef DOWNLOADMANAGER_DEBUG
+    qDebug() << "DownloadItem::" << __FUNCTION__ << m_reply->errorString() << m_url;
+#endif
+
     downloadInfoLabel->setText(tr("Network Error: %1").arg(m_reply->errorString()));
     tryAgainButton->setEnabled(true);
     tryAgainButton->setVisible(true);
@@ -300,89 +327,96 @@ void DownloadItem::metaDataChanged()
         init();
         return;
     }
-    qDebug() << "DownloadItem::metaDataChanged: not handled.";
+
+#ifdef DOWNLOADMANAGER_DEBUG
+    qDebug() << "DownloadItem::" << __FUNCTION__ << "not handled.";
+#endif
 }
 
 void DownloadItem::downloadProgress(qint64 bytesReceived, qint64 bytesTotal)
 {
     m_bytesReceived = bytesReceived;
-    if (bytesTotal == -1) {
-        progressBar->setValue(0);
-        progressBar->setMaximum(0);
-    } else {
-        progressBar->setValue(bytesReceived);
-        progressBar->setMaximum(bytesTotal);
+    qint64 currentValue = 0;
+    qint64 totalValue = 0;
+    if (bytesTotal > 0) {
+        currentValue = bytesReceived * 100 / bytesTotal;
+        totalValue = 100;
     }
+    progressBar->setValue(currentValue);
+    progressBar->setMaximum(totalValue);
+
+    emit progress(currentValue, totalValue);
     updateInfoLabel();
 }
 
+qint64 DownloadItem::bytesTotal() const
+{
+    return m_reply->header(QNetworkRequest::ContentLengthHeader).toULongLong();
+}
+
+qint64 DownloadItem::bytesReceived() const
+{
+    return m_bytesReceived;
+}
+
+double DownloadItem::remainingTime() const
+{
+    if (!downloading())
+        return -1.0;
+
+    double timeRemaining = ((double)(bytesTotal() - bytesReceived())) / currentSpeed();
+
+    // When downloading the eta should never be 0
+    if (timeRemaining == 0)
+        timeRemaining = 1;
+
+    return timeRemaining;
+}
+
+double DownloadItem::currentSpeed() const
+{
+    if (!downloading())
+        return -1.0;
+
+    return m_bytesReceived * 1000.0 / m_downloadTime.elapsed();
+}
+
 void DownloadItem::updateInfoLabel()
 {
     if (m_reply->error() != QNetworkReply::NoError)
         return;
 
-    qint64 bytesTotal = progressBar->maximum();
+    qint64 bytesTotal = m_reply->header(QNetworkRequest::ContentLengthHeader).toULongLong();
     bool running = !downloadedSuccessfully();
 
     // update info label
-    double speed = m_bytesReceived * 1000.0 / m_downloadTime.elapsed();
-    double timeRemaining = ((double)(bytesTotal - m_bytesReceived)) / speed;
-    QString timeRemainingString = tr("seconds");
-
-
-    // When downloading the eta should never be 0
-    if (timeRemaining == 0)
-        timeRemaining = 1;
+    double speed = currentSpeed();
+    double timeRemaining = remainingTime();
 
     QString info;
     if (running) {
         QString remaining;
 
         if (bytesTotal != 0) {
-            if (timeRemaining > 60) {
-                timeRemaining = timeRemaining / 60;
-                timeRemaining = floor(timeRemaining);
-                remaining = tr("- %n minutes remaining", "", int(timeRemaining));
-            }
-            else {
-                timeRemaining = floor(timeRemaining);
-                remaining = tr("- %n seconds remaining", "", int(timeRemaining));
-            }
+            remaining = DownloadManager::timeString(timeRemaining);
         }
-        info = QString(tr("%1 of %2 (%3/sec) %4"))
-            .arg(dataString(m_bytesReceived))
-            .arg(bytesTotal == 0 ? tr("?") : dataString(bytesTotal))
-            .arg(dataString((int)speed))
+
+        info = QString(tr("%1 of %2 (%3/sec) - %4"))
+            .arg(DownloadManager::dataString(m_bytesReceived))
+            .arg(bytesTotal == 0 ? tr("?") : DownloadManager::dataString(bytesTotal))
+            .arg(DownloadManager::dataString((int)speed))
             .arg(remaining);
     } else {
         if (m_bytesReceived == bytesTotal)
-            info = dataString(m_output.size());
+            info = DownloadManager::dataString(m_output.size());
         else
             info = tr("%1 of %2 - Stopped")
-                .arg(dataString(m_bytesReceived))
-                .arg(dataString(bytesTotal));
+                .arg(DownloadManager::dataString(m_bytesReceived))
+                .arg(DownloadManager::dataString(bytesTotal));
     }
     downloadInfoLabel->setText(info);
 }
 
-QString DownloadItem::dataString(int size) const
-{
-    QString unit;
-    double newSize;
-
-    if (size < 1024) {
-        newSize = size;
-        unit = tr("bytes");
-    } else if (size < 1024 * 1024) {
-        newSize = (double)size / (double)1024;
-        unit = tr("kB");
-    } else {
-        newSize = (double)size / (double)(1024 * 1024);
-        unit = tr("MB");
-    }
-    return QString(QLatin1String("%1 %2")).arg(newSize, 0, 'f', 1).arg(unit);
-}
-
 bool DownloadItem::downloading() const
 {
     return (progressBar->isVisible());
@@ -402,6 +436,7 @@ void DownloadItem::finished()
     progressBar->hide();
     stopButton->setEnabled(false);
     stopButton->hide();
+    openButton->setEnabled(true);
     m_output.close();
     updateInfoLabel();
     emit statusChanged();
@@ -429,7 +464,7 @@ DownloadManager::DownloadManager(QWidget *parent)
     downloadsView->horizontalHeader()->setStretchLastSection(true);
     downloadsView->setModel(m_model);
     connect(cleanupButton, SIGNAL(clicked()), this, SLOT(cleanup()));
-    connect(closeButton, SIGNAL(clicked()), this, SLOT(close()));
+    connect(buttonBox, SIGNAL(rejected()), this, SLOT(close()));
     load();
 }
 
@@ -451,6 +486,22 @@ int DownloadManager::activeDownloads() const
     return count;
 }
 
+bool DownloadManager::allowQuit()
+{
+    if (activeDownloads() >= 1) {
+        int choice = QMessageBox::warning(this, QString(),
+                                        tr("There are %1 downloads in progress\n"
+                                           "Do you want to quit anyway?").arg(activeDownloads()),
+                                        QMessageBox::Yes | QMessageBox::No,
+                                        QMessageBox::No);
+        if (choice == QMessageBox::No) {
+            show();
+            return false;
+        }
+    }
+    return true;
+}
+
 void DownloadManager::download(const QNetworkRequest &request, bool requestFileName)
 {
     if (request.url().isEmpty())
@@ -468,9 +519,18 @@ void DownloadManager::handleUnsupportedContent(QNetworkReply *reply, bool reques
     if (ok && size == 0)
         return;
 
-    qDebug() << "DownloadManager::handleUnsupportedContent" << reply->url() << "requestFileName" << requestFileName;
+#ifdef DOWNLOADMANAGER_DEBUG
+    qDebug() << "DownloadManager::" << __FUNCTION__ << reply->url() << "requestFileName" << requestFileName;
+#endif
+
     DownloadItem *item = new DownloadItem(reply, requestFileName, this);
     addItem(item);
+
+    if (!isVisible())
+        show();
+
+    activateWindow();
+    raise();
 }
 
 void DownloadManager::addItem(DownloadItem *item)
@@ -481,8 +541,6 @@ void DownloadManager::addItem(DownloadItem *item)
     m_downloads.append(item);
     m_model->endInsertRows();
     updateItemCount();
-    if (row == 0)
-        show();
     downloadsView->setIndexWidget(m_model->index(row, 0), item);
     QIcon icon = style()->standardIcon(QStyle::SP_FileIcon);
     item->fileIcon->setPixmap(icon.pixmap(48, 48));
@@ -621,6 +679,45 @@ void DownloadManager::updateItemCount()
     itemCount->setText(tr("%n Download(s)", "", count));
 }
 
+QString DownloadManager::timeString(double timeRemaining)
+{
+    QString remaining;
+
+    if (timeRemaining > 60) {
+        timeRemaining = timeRemaining / 60;
+        timeRemaining = floor(timeRemaining);
+        remaining = tr("%n minutes remaining", "", int(timeRemaining));
+    }
+    else {
+        timeRemaining = floor(timeRemaining);
+        remaining = tr("%n seconds remaining", "", int(timeRemaining));
+    }
+
+    return remaining;
+}
+
+QString DownloadManager::dataString(qint64 size)
+{
+    QString unit;
+    double newSize;
+
+    if (size < 1024) {
+        newSize = size;
+        unit = tr("bytes");
+    } else if (size < 1024 * 1024) {
+        newSize = (double)size / (double)1024;
+        unit = tr("kB");
+    } else if (size < 1024 * 1024 * 1024) {
+        newSize = (double)size / (double)(1024 * 1024);
+        unit = tr("MB");
+    } else {
+        newSize = (double)size / (double)(1024 * 1024 * 1024);
+        unit = tr("GB");
+    }
+
+    return QString(QLatin1String("%1 %2")).arg(newSize, 0, 'f', 1).arg(unit);
+}
+
 DownloadModel::DownloadModel(DownloadManager *downloadManager, QObject *parent)
     : QAbstractListModel(parent)
     , m_downloadManager(downloadManager)
