@@ -5,7 +5,7 @@
     <name>AboutDialog</name>
     <message>
         <source>About</source>
-        <translation>À propos</translation>
+        <translation type="obsolete">À propos</translation>
     </message>
     <message>
         <source>Authors</source>
@@ -28,11 +28,42 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <source>About %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message utf8="true">
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AcceptLanguage</name>
+    <message>
+        <source>Languages</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Languages: in order of preference:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move &amp;Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move &amp;Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add...</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -46,6 +77,18 @@ p, li { white-space: pre-wrap; }
         <source>Type a name for the bookmark, and choose where to keep it.</source>
         <translation>Entrer un nom pour le marque-page et choisissez où le conserver.</translation>
     </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">Titre</translation>
+    </message>
+    <message>
+        <source>Add Folder</source>
+        <translation type="unfinished">Ajouter un dossier</translation>
+    </message>
 </context>
 <context>
     <name>BookmarksDialog</name>
@@ -106,10 +149,6 @@ p, li { white-space: pre-wrap; }
         <source>Open File</source>
         <translation>Ouvrir un fichier</translation>
     </message>
-    <message>
-        <source>XBEL (*.xbel *.xml)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Imported %1</source>
         <translation>%1 a été importé</translation>
@@ -140,11 +179,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Name Change</source>
-        <translation>Changement de nom</translation>
+        <translation type="obsolete">Changement de nom</translation>
     </message>
     <message>
         <source>Address Change</source>
-        <translation>Changement d&apos;adresse</translation>
+        <translation type="obsolete">Changement d&apos;adresse</translation>
     </message>
     <message>
         <source>Bookmarks Bar</source>
@@ -154,6 +193,48 @@ p, li { white-space: pre-wrap; }
         <source>Bookmarks Menu</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Name Change</source>
+        <comment>Undo bookmark title change</comment>
+        <translation type="unfinished">Changement de nom</translation>
+    </message>
+    <message>
+        <source>Address Change</source>
+        <comment>Undo bookmark url change</comment>
+        <translation type="unfinished">Changement d&apos;adresse</translation>
+    </message>
+    <message>
+        <source>XBEL bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>HTML Netscape bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>htmlToXBel tool required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading Bookmark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error when loading HTML bookmarks: %1
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>BookmarksMenu</name>
+    <message>
+        <source>Open in Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BookmarksModel</name>
@@ -170,7 +251,7 @@ p, li { white-space: pre-wrap; }
     <name>BookmarksToolBar</name>
     <message>
         <source>Bookmark</source>
-        <translation>Marque-page</translation>
+        <translation type="obsolete">Marque-page</translation>
     </message>
     <message>
         <source>Open</source>
@@ -188,6 +269,14 @@ p, li { white-space: pre-wrap; }
         <source>Add Bookmark...</source>
         <translation type="unfinished">Ajouter un marque-page...</translation>
     </message>
+    <message>
+        <source>Add Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bookmarks</source>
+        <translation type="unfinished">Marque-pages</translation>
+    </message>
 </context>
 <context>
     <name>BrowserApplication</name>
@@ -201,10 +290,6 @@ Voulez-vous tout de même quitter?</translation>
         <source>Restore failed</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source> (Change: %1 %2)</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
         <translation type="unfinished"></translation>
@@ -386,7 +471,7 @@ Voulez-vous tout de même quitter?</translation>
     </message>
     <message>
         <source>Manage Bookmarks...</source>
-        <translation>Gérer les marque-pages</translation>
+        <translation type="obsolete">Gérer les marque-pages</translation>
     </message>
     <message>
         <source>Add Bookmark...</source>
@@ -423,7 +508,7 @@ Voulez-vous tout de même quitter?</translation>
     </message>
     <message>
         <source>About &amp;Arora</source>
-        <translation>À propos d&apos;&amp;Arora</translation>
+        <translation type="obsolete">À propos d&apos;&amp;Arora</translation>
     </message>
     <message>
         <source>Navigation</source>
@@ -453,10 +538,6 @@ Voulez-vous tout de même quitter?</translation>
         <source>Hide Bookmarks bar</source>
         <translation type="obsolete">Masquer la barre de marque-pages</translation>
     </message>
-    <message>
-        <source>Arora</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1 - Arora</source>
         <comment>Page title and Browser name</comment>
@@ -511,11 +592,6 @@ Do you want to reload all pages?</source>
         <source>Downloads</source>
         <translation>Téléchargements</translation>
     </message>
-    <message>
-        <source>Alt+Ctrl+L</source>
-        <comment>Download Manager</comment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Clear Private Data</source>
         <translation>&amp;Effacer l&apos;information privée</translation>
@@ -533,18 +609,6 @@ Do you want to reload all pages?</source>
         <source>&amp;Reload Page</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Make Text &amp;Bigger</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Make Text &amp;Normal</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Make Text &amp;Smaller</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Show Bookmarks Bar</source>
         <translation type="unfinished"></translation>
@@ -553,10 +617,6 @@ Do you want to reload all pages?</source>
         <source>Hide Bookmarks Bar</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Find Nex&amp;t</source>
         <translation type="unfinished"></translation>
@@ -570,11 +630,57 @@ Do you want to reload all pages?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show &amp;Network Monitor</source>
+        <source>Switch application language </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Switch application language </source>
+        <source>Close Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;In</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Normal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Text Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show All Bookmarks...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About &amp;%1</source>
+        <comment>About Browser</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Y</source>
+        <comment>Download Manager</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text Encoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -632,6 +738,40 @@ Do you want to reload all pages?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>ClickToFlash</name>
+    <message>
+        <source>Load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add %1 to Whitelist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove from Whitelist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished">Paramètres</translation>
+    </message>
+    <message>
+        <source>Load Flash</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ClickToFlashSettings</name>
+    <message>
+        <source>Whitelist sites</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CookieExceptionsModel</name>
     <message>
@@ -693,6 +833,10 @@ Do you want to reload all pages?</source>
         <source>false</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Session cookie</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CookiesDialog</name>
@@ -708,6 +852,10 @@ Do you want to reload all pages?</source>
         <source>Remove &amp;All Cookies</source>
         <translation>Retirer tous les fichiers témoins</translation>
     </message>
+    <message>
+        <source>Add &amp;Rule</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CookiesExceptionsDialog</name>
@@ -762,16 +910,12 @@ Do you want to reload all pages?</source>
         <source>0 Items</source>
         <translation>0 items</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>DownloadItem</name>
     <message>
         <source>Form</source>
-        <translation>Formulaire</translation>
+        <translation type="obsolete">Formulaire</translation>
     </message>
     <message>
         <source>Ico</source>
@@ -815,7 +959,7 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>seconds</source>
-        <translation>secondes</translation>
+        <translation type="obsolete">secondes</translation>
     </message>
     <message>
         <source>minutes</source>
@@ -827,7 +971,7 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>%1 of %2 (%3/sec) %4</source>
-        <translation>%1 de %2 (%3/sec) %4</translation>
+        <translation type="obsolete">%1 de %2 (%3/sec) %4</translation>
     </message>
     <message>
         <source>?</source>
@@ -839,34 +983,28 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>bytes</source>
-        <translation>octets</translation>
+        <translation type="obsolete">octets</translation>
     </message>
     <message>
         <source>kB</source>
-        <translation>kO</translation>
+        <translation type="obsolete">kO</translation>
     </message>
     <message>
         <source>MB</source>
-        <translation>MO</translation>
-    </message>
-    <message numerus="yes">
-        <source>- %n minutes remaining</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>- %n seconds remaining</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-            <numerusform></numerusform>
-        </translation>
+        <translation type="obsolete">MO</translation>
     </message>
     <message>
         <source>Error opening output file: %1</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 of %2 (%3/sec) - %4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Download directory (%1) couldn&apos;t be created.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DownloadManager</name>
@@ -885,6 +1023,64 @@ Do you want to reload all pages?</source>
             <numerusform></numerusform>
         </translation>
     </message>
+    <message>
+        <source>There are %1 downloads in progress
+Do you want to quit anyway?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minutes remaining</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n seconds remaining</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>bytes</source>
+        <translation type="unfinished">octets</translation>
+    </message>
+    <message>
+        <source>kB</source>
+        <translation type="unfinished">kO</translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation type="unfinished">MO</translation>
+    </message>
+    <message>
+        <source>GB</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileAccessReply</name>
+    <message>
+        <source>No Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error opening: %1: No such file or directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to read %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Contents of %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 KB</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HistoryDialog</name>
@@ -962,11 +1158,30 @@ Do you want to reload all pages?</source>
     </message>
 </context>
 <context>
-    <name>LanguageManager</name>
+    <name>JavaScriptAroraObject</name>
     <message>
-        <source>Default</source>
+        <source>Welcome to Arora!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Arora Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search results provided by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Arora</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LanguageManager</name>
     <message>
         <source>Choose language</source>
         <translation type="unfinished"></translation>
@@ -975,6 +1190,10 @@ Do you want to reload all pages?</source>
         <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No translation files are installed.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NetworkAccessManager</name>
@@ -994,51 +1213,111 @@ Do you want to reload all pages?</source>
 %2
 
 Do you want to ignore these errors?</source>
-        <translation>Erreurs SSL:
+        <translation type="obsolete">Erreurs SSL:
 %1
 %2
 Voulez-vous ignorer ses erreurs?</translation>
     </message>
     <message>
         <source>Do you want to accept all these certificates?</source>
-        <translation>Voulez-vous accepter tous ces certificats?</translation>
+        <translation type="obsolete">Voulez-vous accepter tous ces certificats?</translation>
+    </message>
+    <message>
+        <source> - SSL Errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;
+
+Do you want to ignore these errors?&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Issuer: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not valid before: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid until: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alternate Names:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>NetworkMonitor</name>
     <message>
         <source>Name</source>
-        <translation type="unfinished">Nom</translation>
+        <translation type="obsolete">Nom</translation>
+    </message>
+</context>
+<context>
+    <name>OpenSearchDialog</name>
+    <message>
+        <source>Open File</source>
+        <translation type="unfinished">Ouvrir un fichier</translation>
     </message>
     <message>
-        <source>Value</source>
+        <source>OpenSearch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must have at least one search engine in here.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OpenSearch Manager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Restore Defaults</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>NetworkMonitorDialog</name>
+    <name>OpenSearchEngineModel</name>
     <message>
-        <source>Network Monitor</source>
+        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Network Requests</source>
+        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>OpenSearchManager</name>
     <message>
-        <source>Request Headers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Response Headers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Remove</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Remove &amp;All Requests</source>
+        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1078,10 +1357,6 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Proxy Authentication</source>
         <translation>Authentification au serveur mandataire</translation>
     </message>
-    <message>
-        <source>ICON</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Connect to proxy</source>
         <translation>Se brancher au serveur mandataire</translation>
@@ -1105,60 +1380,32 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Unknown title</source>
         <translation>Titre inconnu</translation>
     </message>
+    <message>
+        <source>The file is not an OpenSearch 1.1 file.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RequestModel</name>
-    <message>
-        <source>Redirect: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Method</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Address</source>
-        <translation type="unfinished">Adresse</translation>
-    </message>
-    <message>
-        <source>Response</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Length</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Content Type</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Info</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Adresse</translation>
     </message>
 </context>
 <context>
     <name>SearchBanner</name>
     <message>
         <source>Form</source>
-        <translation>Fromulaire</translation>
-    </message>
-    <message>
-        <source>TextLabel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&lt;</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Fromulaire</translation>
     </message>
     <message>
         <source>Done</source>
         <translation>Fermer</translation>
     </message>
+    <message>
+        <source>Highlight All</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -1219,7 +1466,7 @@ Voulez-vous ignorer ses erreurs?</translation>
     </message>
     <message>
         <source>In a tab in the current window</source>
-        <translation>Dans un onglet dans la fenêtre en cours</translation>
+        <translation type="obsolete">Dans un onglet dans la fenêtre en cours</translation>
     </message>
     <message>
         <source>In a new window</source>
@@ -1233,10 +1480,6 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Standard font:</source>
         <translation>Police par défaut:</translation>
     </message>
-    <message>
-        <source>Times 16</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Select...</source>
         <translation>Sélectionner...</translation>
@@ -1245,10 +1488,6 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Fixed-width font:</source>
         <translation>Police à espacement constant:</translation>
     </message>
-    <message>
-        <source>Courier 13</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Privacy</source>
         <translation>Vie privée</translation>
@@ -1325,10 +1564,6 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Socks5</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Http</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Host:</source>
         <translation type="obsolete">Hôte:</translation>
@@ -1393,10 +1628,6 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Select tabs and windows as they are created</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Confirm when closing multiple tabs</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Preferences</source>
         <translation type="unfinished"></translation>
@@ -1425,6 +1656,85 @@ Voulez-vous ignorer ses erreurs?</translation>
         <source>Host name:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Preferred languages for viewing webpages in:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Block Popup Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Opening links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Links that want to open in a new window:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In a new selected tab in the current window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In a new tab in the current window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In the current tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Http (Secure)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Http (Transparent)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use ClickToFlash on flash plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter Tracking Cookies</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm when closing multiple tabs or windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quit the application when last tab is closed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable network cache</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maximum Size:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> MB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsDialog</name>
+    <message>
+        <source>Restart required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SourceViewer</name>
@@ -1449,7 +1759,7 @@ Voulez-vous ignorer ses erreurs?</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Source of Page </source>
+        <source>Source of Page %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1457,7 +1767,7 @@ Voulez-vous ignorer ses erreurs?</translation>
     <name>TabBar</name>
     <message>
         <source>New &amp;Tab</source>
-        <translation>Nouvel onglet</translation>
+        <translation type="obsolete">Nouvel onglet</translation>
     </message>
     <message>
         <source>Duplicate Tab</source>
@@ -1538,6 +1848,30 @@ Voulez-vous vraiment fermer cette page?
         <source>Untitled</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Saved Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading %1% (%2 %3)...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Finished loading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bookmark All Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ToolbarSearch</name>
@@ -1551,7 +1885,19 @@ Voulez-vous vraiment fermer cette page?
     </message>
     <message>
         <source>Clear Recent Searches</source>
-        <translation>Effacer les recherches récentes</translation>
+        <translation type="unfinished">Effacer les recherches récentes</translation>
+    </message>
+    <message>
+        <source>Suggestions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure Search Engines...</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1569,11 +1915,19 @@ Voulez-vous vraiment fermer cette page?
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If the address is correct, try to check the network connection.</source>
+        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
+        <source>If the address is correct, try checking the network connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resending POST request</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1623,6 +1977,38 @@ Voulez-vous vraiment fermer cette page?
         <source>Loading...</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Search with...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add to the toolbar search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Method not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 method is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Choose the desired search engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Engine name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type in a name for the engine</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WebViewSearch</name>
