@@ -1,12 +1,11 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="he_IL">
-<defaultcodec></defaultcodec>
 <context>
     <name>AboutDialog</name>
     <message>
         <source>About</source>
-        <translation>אודות</translation>
+        <translation type="obsolete">אודות</translation>
     </message>
     <message>
         <source>Authors</source>
@@ -41,11 +40,42 @@ p, li { white-space: pre-wrap; }
         <translation>סגור</translation>
     </message>
     <message>
+        <source>About %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message utf8="true">
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AcceptLanguage</name>
+    <message>
+        <source>Languages</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Languages: in order of preference:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move &amp;Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move &amp;Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Remove</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add...</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -59,6 +89,18 @@ p, li { white-space: pre-wrap; }
         <source>Type a name for the bookmark, and choose where to keep it.</source>
         <translation>כתוב שם עבור הסימנית ובחר היכן לשמור אותה.</translation>
     </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">כותרת</translation>
+    </message>
+    <message>
+        <source>Add Folder</source>
+        <translation type="unfinished">הוסף תיקייה</translation>
+    </message>
 </context>
 <context>
     <name>BookmarksDialog</name>
@@ -121,7 +163,7 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>XBEL (*.xbel *.xml)</source>
-        <translation>XBEL (*.xbel *.xml)</translation>
+        <translation type="obsolete">XBEL (*.xbel *.xml)</translation>
     </message>
     <message>
         <source>Imported %1</source>
@@ -153,11 +195,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Name Change</source>
-        <translation>שנה שם</translation>
+        <translation type="obsolete">שנה שם</translation>
     </message>
     <message>
         <source>Address Change</source>
-        <translation>שנה כתובת</translation>
+        <translation type="obsolete">שנה כתובת</translation>
     </message>
     <message>
         <source>Bookmarks Bar</source>
@@ -167,6 +209,48 @@ p, li { white-space: pre-wrap; }
         <source>Bookmarks Menu</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Name Change</source>
+        <comment>Undo bookmark title change</comment>
+        <translation type="unfinished">שנה שם</translation>
+    </message>
+    <message>
+        <source>Address Change</source>
+        <comment>Undo bookmark url change</comment>
+        <translation type="unfinished">שנה כתובת</translation>
+    </message>
+    <message>
+        <source>XBEL bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>HTML Netscape bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>htmlToXBel tool required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading Bookmark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error when loading HTML bookmarks: %1
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>BookmarksMenu</name>
+    <message>
+        <source>Open in Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BookmarksModel</name>
@@ -183,7 +267,7 @@ p, li { white-space: pre-wrap; }
     <name>BookmarksToolBar</name>
     <message>
         <source>Bookmark</source>
-        <translation>סימניות</translation>
+        <translation type="obsolete">סימניות</translation>
     </message>
     <message>
         <source>Open</source>
@@ -201,12 +285,20 @@ p, li { white-space: pre-wrap; }
         <source>Add Bookmark...</source>
         <translation type="unfinished">הוסף סימנייה...</translation>
     </message>
+    <message>
+        <source>Add Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bookmarks</source>
+        <translation type="unfinished">סימניות</translation>
+    </message>
 </context>
 <context>
     <name>BrowserApplication</name>
     <message>
         <source> (Change: %1 %2)</source>
-        <translation>(שינוי %1 %2)</translation>
+        <translation type="obsolete">(שינוי %1 %2)</translation>
     </message>
     <message>
         <source>There are %1 windows and %2 tabs open
@@ -343,15 +435,15 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>Make Text &amp;Bigger</source>
-        <translation>&amp;הגדל גופן</translation>
+        <translation type="obsolete">&amp;הגדל גופן</translation>
     </message>
     <message>
         <source>Make Text &amp;Normal</source>
-        <translation>גופן &amp;רגיל</translation>
+        <translation type="obsolete">גופן &amp;רגיל</translation>
     </message>
     <message>
         <source>Make Text &amp;Smaller</source>
-        <translation>ה&amp;קטן גופן</translation>
+        <translation type="obsolete">ה&amp;קטן גופן</translation>
     </message>
     <message>
         <source>Page S&amp;ource</source>
@@ -391,7 +483,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>Manage Bookmarks...</source>
-        <translation>ניהול סימניות...</translation>
+        <translation type="obsolete">ניהול סימניות...</translation>
     </message>
     <message>
         <source>Add Bookmark...</source>
@@ -437,7 +529,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>About &amp;Arora</source>
-        <translation>א&amp;ודות Arora</translation>
+        <translation type="obsolete">א&amp;ודות Arora</translation>
     </message>
     <message>
         <source>Navigation</source>
@@ -469,7 +561,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>Arora</source>
-        <translation>Arora</translation>
+        <translation type="obsolete">Arora</translation>
     </message>
     <message>
         <source>%1 - Arora</source>
@@ -494,7 +586,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
-        <translation>&lt;span dir=&quot;rtl&quot;&gt;&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;כאשר מופעלת גלישה מאובטחת כמה פעולות הקשורות לפרטיות שלך לא יופעלו:&lt;ul dir=&quot;rtl&quot;&gt;&lt;li&gt; דפים לא נוספים להסטוריית הגלישה.&lt;/li&gt;&lt;li&gt; פריטים נמחקים באופן אוטומטי מרשימת ההורדות.&lt;/li&gt;&lt;li&gt; עוגיות חדשות לא נשמרות ואין אפשרות לגשת לעוגיות ישנות.&lt;/li&gt;&lt;li&gt; סמלים של אתרים לא נשמרים וההפעלה לא תישמר.&lt;/li&gt;&lt;li&gt; חיפושים לא מתווספים לתפריט המוקפץ של היסטוריית החיפוש.&lt;/li&gt;&lt;/ul&gt;עד שתסגור את החלון, באפשרותך ללחוץ על כפתורי הניווט &quot;קדימה&quot; ו־&quot;אחורה&quot; לחזרה לעמודים שביקרת בהם.
+        <translation type="obsolete">&lt;span dir=&quot;rtl&quot;&gt;&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;כאשר מופעלת גלישה מאובטחת כמה פעולות הקשורות לפרטיות שלך לא יופעלו:&lt;ul dir=&quot;rtl&quot;&gt;&lt;li&gt; דפים לא נוספים להסטוריית הגלישה.&lt;/li&gt;&lt;li&gt; פריטים נמחקים באופן אוטומטי מרשימת ההורדות.&lt;/li&gt;&lt;li&gt; עוגיות חדשות לא נשמרות ואין אפשרות לגשת לעוגיות ישנות.&lt;/li&gt;&lt;li&gt; סמלים של אתרים לא נשמרים וההפעלה לא תישמר.&lt;/li&gt;&lt;li&gt; חיפושים לא מתווספים לתפריט המוקפץ של היסטוריית החיפוש.&lt;/li&gt;&lt;/ul&gt;עד שתסגור את החלון, באפשרותך ללחוץ על כפתורי הניווט &quot;קדימה&quot; ו־&quot;אחורה&quot; לחזרה לעמודים שביקרת בהם.
 &lt;/span&gt;</translation>
     </message>
     <message>
@@ -530,16 +622,62 @@ Do you want to reload all pages?</source>
     <message>
         <source>Alt+Ctrl+L</source>
         <comment>Download Manager</comment>
-        <translation>Alt+Ctrl+L</translation>
-    </message>
-    <message>
-        <source>Show &amp;Network Monitor</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Alt+Ctrl+L</translation>
     </message>
     <message>
         <source>Switch application language </source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Close Window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;In</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Normal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Text Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show All Bookmarks...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About &amp;%1</source>
+        <comment>About Browser</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Y</source>
+        <comment>Download Manager</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Text Encoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ClearButton</name>
@@ -591,6 +729,40 @@ Do you want to reload all pages?</source>
         <translation>&amp;ביטול</translation>
     </message>
 </context>
+<context>
+    <name>ClickToFlash</name>
+    <message>
+        <source>Load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add %1 to Whitelist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove from Whitelist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load Flash</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ClickToFlashSettings</name>
+    <message>
+        <source>Whitelist sites</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CookieExceptionsModel</name>
     <message>
@@ -648,6 +820,10 @@ Do you want to reload all pages?</source>
         <source>false</source>
         <translation>false</translation>
     </message>
+    <message>
+        <source>Session cookie</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CookiesDialog</name>
@@ -663,6 +839,10 @@ Do you want to reload all pages?</source>
         <source>Remove &amp;All Cookies</source>
         <translation>מחק את &amp;כל העוגיות</translation>
     </message>
+    <message>
+        <source>Add &amp;Rule</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CookiesExceptionsDialog</name>
@@ -719,14 +899,14 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>&amp;OK</source>
-        <translation>&amp;אישור</translation>
+        <translation type="obsolete">&amp;אישור</translation>
     </message>
 </context>
 <context>
     <name>DownloadItem</name>
     <message>
         <source>Form</source>
-        <translation>ממקום</translation>
+        <translation type="obsolete">ממקום</translation>
     </message>
     <message>
         <source>Ico</source>
@@ -770,25 +950,25 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>seconds</source>
-        <translation>שניות</translation>
+        <translation type="obsolete">שניות</translation>
     </message>
     <message numerus="yes">
         <source>- %n minutes remaining</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>נשארו עוד %n שניות</numerusform>
             <numerusform></numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <source>- %n seconds remaining</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>נשארו עוד %n דקות</numerusform>
             <numerusform></numerusform>
         </translation>
     </message>
     <message>
         <source>%1 of %2 (%3/sec) %4</source>
-        <translation>%1 מתוך %2 (%3 קס&quot;ש) %2</translation>
+        <translation type="obsolete">%1 מתוך %2 (%3 קס&quot;ש) %2</translation>
     </message>
     <message>
         <source>?</source>
@@ -800,15 +980,23 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>bytes</source>
-        <translation>בתים</translation>
+        <translation type="obsolete">בתים</translation>
     </message>
     <message>
         <source>kB</source>
-        <translation>ק&quot;ב</translation>
+        <translation type="obsolete">ק&quot;ב</translation>
     </message>
     <message>
         <source>MB</source>
-        <translation>מ&quot;ב</translation>
+        <translation type="obsolete">מ&quot;ב</translation>
+    </message>
+    <message>
+        <source>%1 of %2 (%3/sec) - %4</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Download directory (%1) couldn&apos;t be created.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -820,6 +1008,64 @@ Do you want to reload all pages?</source>
             <numerusform>%n הורדות</numerusform>
         </translation>
     </message>
+    <message>
+        <source>There are %1 downloads in progress
+Do you want to quit anyway?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minutes remaining</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n seconds remaining</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>bytes</source>
+        <translation type="unfinished">בתים</translation>
+    </message>
+    <message>
+        <source>kB</source>
+        <translation type="unfinished">ק&quot;ב</translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation type="unfinished">מ&quot;ב</translation>
+    </message>
+    <message>
+        <source>GB</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileAccessReply</name>
+    <message>
+        <source>No Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error opening: %1: No such file or directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to read %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Contents of %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 KB</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HistoryDialog</name>
@@ -893,11 +1139,30 @@ Do you want to reload all pages?</source>
     </message>
 </context>
 <context>
-    <name>LanguageManager</name>
+    <name>JavaScriptAroraObject</name>
     <message>
-        <source>Default</source>
+        <source>Welcome to Arora!</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Arora Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search results provided by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Arora</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>LanguageManager</name>
     <message>
         <source>Choose language</source>
         <translation type="unfinished"></translation>
@@ -906,6 +1171,10 @@ Do you want to reload all pages?</source>
         <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No translation files are installed.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NetworkAccessManager</name>
@@ -925,51 +1194,111 @@ Do you want to reload all pages?</source>
 %2
 
 Do you want to ignore these errors?</source>
-        <translation>שגיאות SSL:&lt;div dir=&quot;ltr&quot;&gt;￼%1￼
+        <translation type="obsolete">שגיאות SSL:&lt;div dir=&quot;ltr&quot;&gt;￼%1￼
 ￼%2￼
 &lt;/div&gt;
 האם ברצונך להתעלם מהשגיאות הללו?￼</translation>
     </message>
     <message>
         <source>Do you want to accept all these certificates?</source>
-        <translation>האם ברצונך לקבל את האישורים הללו?</translation>
+        <translation type="obsolete">האם ברצונך לקבל את האישורים הללו?</translation>
+    </message>
+    <message>
+        <source> - SSL Errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;
+
+Do you want to ignore these errors?&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Issuer: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not valid before: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid until: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alternate Names:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>NetworkMonitor</name>
     <message>
         <source>Name</source>
-        <translation type="unfinished">שם</translation>
+        <translation type="obsolete">שם</translation>
+    </message>
+</context>
+<context>
+    <name>OpenSearchDialog</name>
+    <message>
+        <source>Open File</source>
+        <translation type="unfinished">פתח קובץ</translation>
     </message>
     <message>
-        <source>Value</source>
+        <source>OpenSearch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must have at least one search engine in here.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OpenSearch Manager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Restore Defaults</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
-    <name>NetworkMonitorDialog</name>
+    <name>OpenSearchEngineModel</name>
     <message>
-        <source>Network Monitor</source>
+        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Network Requests</source>
+        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
         <translation type="unfinished"></translation>
     </message>
+</context>
+<context>
+    <name>OpenSearchManager</name>
     <message>
-        <source>Request Headers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Response Headers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Remove</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Remove &amp;All Requests</source>
+        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1011,7 +1340,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>ICON</source>
-        <translation>ICON</translation>
+        <translation type="obsolete">ICON</translation>
     </message>
     <message>
         <source>Connect to proxy</source>
@@ -1036,60 +1365,44 @@ Do you want to ignore these errors?</source>
         <source>Unknown title</source>
         <translation>כותרת לא ידועה</translation>
     </message>
+    <message>
+        <source>The file is not an OpenSearch 1.1 file.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RequestModel</name>
-    <message>
-        <source>Redirect: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Method</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Address</source>
-        <translation type="unfinished">כתובת</translation>
-    </message>
-    <message>
-        <source>Response</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Length</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Content Type</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Info</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">כתובת</translation>
     </message>
 </context>
 <context>
     <name>SearchBanner</name>
     <message>
         <source>Form</source>
-        <translation>מאת</translation>
+        <translation type="obsolete">מאת</translation>
     </message>
     <message>
         <source>TextLabel</source>
-        <translation>TextLabel</translation>
+        <translation type="obsolete">TextLabel</translation>
     </message>
     <message>
         <source>&lt;</source>
-        <translation>&lt;</translation>
+        <translation type="obsolete">&lt;</translation>
     </message>
     <message>
         <source>&gt;</source>
-        <translation>&gt;</translation>
+        <translation type="obsolete">&gt;</translation>
     </message>
     <message>
         <source>Done</source>
         <translation>סיים</translation>
     </message>
+    <message>
+        <source>Highlight All</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -1170,7 +1483,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>In a tab in the current window</source>
-        <translation>בכרטיסייה בחלון הנוכחי</translation>
+        <translation type="obsolete">בכרטיסייה בחלון הנוכחי</translation>
     </message>
     <message>
         <source>In a new window</source>
@@ -1198,7 +1511,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>Times 16</source>
-        <translation>Times 16</translation>
+        <translation type="obsolete">Times 16</translation>
     </message>
     <message>
         <source>Select...</source>
@@ -1210,7 +1523,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>Courier 13</source>
-        <translation>Courier 13</translation>
+        <translation type="obsolete">Courier 13</translation>
     </message>
     <message>
         <source>Privacy</source>
@@ -1286,7 +1599,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>Confirm when closing multiple tabs</source>
-        <translation>וודא יציאה כאשר מספר כרטיסיות פתוחות</translation>
+        <translation type="obsolete">וודא יציאה כאשר מספר כרטיסיות פתוחות</translation>
     </message>
     <message>
         <source>Proxy</source>
@@ -1306,7 +1619,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>Http</source>
-        <translation>Http</translation>
+        <translation type="obsolete">Http</translation>
     </message>
     <message>
         <source>Host name:</source>
@@ -1336,6 +1649,85 @@ Do you want to ignore these errors?</source>
         <source>Show only one close button instead of one for each tab</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Preferred languages for viewing webpages in:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Block Popup Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Opening links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Links that want to open in a new window:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In a new selected tab in the current window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In a new tab in the current window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In the current tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Http (Secure)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Http (Transparent)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use ClickToFlash on flash plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter Tracking Cookies</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm when closing multiple tabs or windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quit the application when last tab is closed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable network cache</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maximum Size:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> MB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsDialog</name>
+    <message>
+        <source>Restart required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SourceViewer</name>
@@ -1360,7 +1752,7 @@ Do you want to ignore these errors?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Source of Page </source>
+        <source>Source of Page %1</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1376,7 +1768,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>New &amp;Tab</source>
-        <translation>כרטיסייה &amp;חדשה</translation>
+        <translation type="obsolete">כרטיסייה &amp;חדשה</translation>
     </message>
     <message>
         <source>Duplicate Tab</source>
@@ -1444,6 +1836,30 @@ Do you really want to close this page?
         <source>Ctrl-[</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Saved Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading...</source>
+        <translation type="unfinished">טוען...</translation>
+    </message>
+    <message>
+        <source>Loading %1% (%2 %3)...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Finished loading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bookmark All Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ToolbarSearch</name>
@@ -1457,7 +1873,19 @@ Do you really want to close this page?
     </message>
     <message>
         <source>Clear Recent Searches</source>
-        <translation>אפס את החיפושים האחרונים</translation>
+        <translation type="unfinished">אפס את החיפושים האחרונים</translation>
+    </message>
+    <message>
+        <source>Suggestions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure Search Engines...</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1475,11 +1903,19 @@ Do you really want to close this page?
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If the address is correct, try to check the network connection.</source>
+        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
+        <source>If the address is correct, try checking the network connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resending POST request</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -1529,6 +1965,38 @@ Do you really want to close this page?
         <source>Loading...</source>
         <translation>טוען...</translation>
     </message>
+    <message>
+        <source>Search with...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add to the toolbar search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Method not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 method is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Choose the desired search engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Engine name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type in a name for the engine</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WebViewSearch</name>
