@@ -1,12 +1,11 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="zh_CN">
-<defaultcodec></defaultcodec>
 <context>
     <name>AboutDialog</name>
     <message>
         <source>About</source>
-        <translation>关于</translation>
+        <translation type="obsolete">关于</translation>
     </message>
     <message>
         <source>Authors</source>
@@ -29,12 +28,43 @@
         <translation>关闭</translation>
     </message>
     <message>
+        <source>About %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message utf8="true">
         <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
 &lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
 p, li { white-space: pre-wrap; }
 &lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
-&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2008 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation></translation>
+&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>AcceptLanguage</name>
+    <message>
+        <source>Languages</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Languages: in order of preference:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move &amp;Up</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Move &amp;Down</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Remove</source>
+        <translation type="unfinished">移除(&amp;R)</translation>
+    </message>
+    <message>
+        <source>Add...</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -47,6 +77,18 @@ p, li { white-space: pre-wrap; }
         <source>Type a name for the bookmark, and choose where to keep it.</source>
         <translation>请输入书签名，并选择保存位置</translation>
     </message>
+    <message>
+        <source>Url</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Title</source>
+        <translation type="unfinished">标题</translation>
+    </message>
+    <message>
+        <source>Add Folder</source>
+        <translation type="unfinished">添加文件夹</translation>
+    </message>
 </context>
 <context>
     <name>BookmarksDialog</name>
@@ -107,10 +149,6 @@ p, li { white-space: pre-wrap; }
         <source>Open File</source>
         <translation>打开文件</translation>
     </message>
-    <message>
-        <source>XBEL (*.xbel *.xml)</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Imported %1</source>
         <translation>导入的%1</translation>
@@ -141,11 +179,11 @@ p, li { white-space: pre-wrap; }
     </message>
     <message>
         <source>Name Change</source>
-        <translation>名字变更</translation>
+        <translation type="obsolete">名字变更</translation>
     </message>
     <message>
         <source>Address Change</source>
-        <translation>地址变更</translation>
+        <translation type="obsolete">地址变更</translation>
     </message>
     <message>
         <source>Bookmarks Bar</source>
@@ -155,6 +193,48 @@ p, li { white-space: pre-wrap; }
         <source>Bookmarks Menu</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Name Change</source>
+        <comment>Undo bookmark title change</comment>
+        <translation type="unfinished">名字变更</translation>
+    </message>
+    <message>
+        <source>Address Change</source>
+        <comment>Undo bookmark url change</comment>
+        <translation type="unfinished">地址变更</translation>
+    </message>
+    <message>
+        <source>XBEL bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>HTML Netscape bookmarks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>htmlToXBel tool required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading Bookmark</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error when loading HTML bookmarks: %1
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>BookmarksMenu</name>
+    <message>
+        <source>Open in Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BookmarksModel</name>
@@ -171,7 +251,7 @@ p, li { white-space: pre-wrap; }
     <name>BookmarksToolBar</name>
     <message>
         <source>Bookmark</source>
-        <translation>书签</translation>
+        <translation type="obsolete">书签</translation>
     </message>
     <message>
         <source>Open</source>
@@ -189,12 +269,20 @@ p, li { white-space: pre-wrap; }
         <source>Add Bookmark...</source>
         <translation type="unfinished">添加标签...</translation>
     </message>
+    <message>
+        <source>Add Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bookmarks</source>
+        <translation type="unfinished">书签</translation>
+    </message>
 </context>
 <context>
     <name>BrowserApplication</name>
     <message>
         <source> (Change: %1 %2)</source>
-        <translation>(变更： %1 %2)</translation>
+        <translation type="obsolete">(变更： %1 %2)</translation>
     </message>
     <message>
         <source>There are %1 windows and %2 tabs open
@@ -331,15 +419,15 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>Make Text &amp;Bigger</source>
-        <translation>字体放大(&amp;B)</translation>
+        <translation type="obsolete">字体放大(&amp;B)</translation>
     </message>
     <message>
         <source>Make Text &amp;Normal</source>
-        <translation>普通字体(&amp;N)</translation>
+        <translation type="obsolete">普通字体(&amp;N)</translation>
     </message>
     <message>
         <source>Make Text &amp;Smaller</source>
-        <translation>字体缩小(&amp;S)</translation>
+        <translation type="obsolete">字体缩小(&amp;S)</translation>
     </message>
     <message>
         <source>Page S&amp;ource</source>
@@ -379,7 +467,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>Manage Bookmarks...</source>
-        <translation>管理标签...</translation>
+        <translation type="obsolete">管理标签...</translation>
     </message>
     <message>
         <source>Add Bookmark...</source>
@@ -429,7 +517,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>About &amp;Arora</source>
-        <translation>关于&amp;Arora</translation>
+        <translation type="obsolete">关于&amp;Arora</translation>
     </message>
     <message>
         <source>Navigation</source>
@@ -459,10 +547,6 @@ Do you want to quit anyway?</source>
         <source>Hide Bookmarks Bar</source>
         <translation>隐藏标签栏</translation>
     </message>
-    <message>
-        <source>Arora</source>
-        <translation></translation>
-    </message>
     <message>
         <source>%1 - Arora</source>
         <comment>Page title and Browser name</comment>
@@ -486,7 +570,7 @@ Do you want to quit anyway?</source>
     </message>
     <message>
         <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
-        <translation>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;当开启隐私浏览时，关于你的某些隐私动作不会被记录：&lt;ul&gt;&lt;li&gt; 页面不会被添加到历史中。&lt;/li&gt;&lt;li&gt;下载项会自动从下载窗口移除。 &lt;/li&gt;&lt;li&gt; 新的cookies不会被存储，当前的cookies也不会被访问。&lt;/li&gt;&lt;li&gt;站点图标不会被存储，会话也不会被保存。 &lt;/li&gt;&lt;li&gt;搜索动作不会被添加到搜索框的弹出菜单中。&lt;/li&gt;&lt;/ul&gt;在关闭窗口之前，你可以一直通过点击后退和前进按钮来浏览已打开过的页面。</translation>
+        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;当开启隐私浏览时，关于你的某些隐私动作不会被记录：&lt;ul&gt;&lt;li&gt; 页面不会被添加到历史中。&lt;/li&gt;&lt;li&gt;下载项会自动从下载窗口移除。 &lt;/li&gt;&lt;li&gt; 新的cookies不会被存储，当前的cookies也不会被访问。&lt;/li&gt;&lt;li&gt;站点图标不会被存储，会话也不会被保存。 &lt;/li&gt;&lt;li&gt;搜索动作不会被添加到搜索框的弹出菜单中。&lt;/li&gt;&lt;/ul&gt;在关闭窗口之前，你可以一直通过点击后退和前进按钮来浏览已打开过的页面。</translation>
     </message>
     <message>
         <source>Are you sure you want to close the window?  There are %1 tabs open</source>
@@ -515,12 +599,53 @@ Do you want to reload all pages?</source>
         <translation>下载</translation>
     </message>
     <message>
-        <source>Alt+Ctrl+L</source>
-        <comment>Download Manager</comment>
-        <translation></translation>
+        <source>Close Window</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show &amp;Network Monitor</source>
+        <source>Zoom &amp;In</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Normal</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Zoom &amp;Text Only</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show All Bookmarks...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add Folder...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About &amp;%1</source>
+        <comment>About Browser</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Y</source>
+        <comment>Download Manager</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Default</source>
+        <translation type="unfinished">缺省</translation>
+    </message>
+    <message>
+        <source>Text Encoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not added to the pop-up menu in the search box.&lt;/li&gt;&lt;li&gt; Network cache is disabled.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -574,6 +699,40 @@ Do you want to reload all pages?</source>
         <translation>取消(&amp;C)</translation>
     </message>
 </context>
+<context>
+    <name>ClickToFlash</name>
+    <message>
+        <source>Load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add %1 to Whitelist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remove from Whitelist</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Load Flash</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>ClickToFlashSettings</name>
+    <message>
+        <source>Whitelist sites</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CookieExceptionsModel</name>
     <message>
@@ -631,6 +790,10 @@ Do you want to reload all pages?</source>
         <source>false</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Session cookie</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CookiesDialog</name>
@@ -646,6 +809,10 @@ Do you want to reload all pages?</source>
         <source>Remove &amp;All Cookies</source>
         <translation>移除所有Cookies(&amp;A)</translation>
     </message>
+    <message>
+        <source>Add &amp;Rule</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CookiesExceptionsDialog</name>
@@ -700,16 +867,12 @@ Do you want to reload all pages?</source>
         <source>0 Items</source>
         <translation>0项</translation>
     </message>
-    <message>
-        <source>&amp;OK</source>
-        <translation></translation>
-    </message>
 </context>
 <context>
     <name>DownloadItem</name>
     <message>
         <source>Form</source>
-        <translation>表单</translation>
+        <translation type="obsolete">表单</translation>
     </message>
     <message>
         <source>Ico</source>
@@ -753,23 +916,23 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>seconds</source>
-        <translation>秒</translation>
+        <translation type="obsolete">秒</translation>
     </message>
     <message numerus="yes">
         <source>- %n minutes remaining</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>- 还有 %n 分钟</numerusform>
         </translation>
     </message>
     <message numerus="yes">
         <source>- %n seconds remaining</source>
-        <translation>
+        <translation type="obsolete">
             <numerusform>- 还有 %n 秒</numerusform>
         </translation>
     </message>
     <message>
         <source>%1 of %2 (%3/sec) %4</source>
-        <translation>%1 of %2 (%3/秒) %4</translation>
+        <translation type="obsolete">%1 of %2 (%3/秒) %4</translation>
     </message>
     <message>
         <source>?</source>
@@ -781,15 +944,15 @@ Do you want to reload all pages?</source>
     </message>
     <message>
         <source>bytes</source>
-        <translation>字节</translation>
+        <translation type="obsolete">字节</translation>
     </message>
     <message>
-        <source>kB</source>
-        <translation></translation>
+        <source>%1 of %2 (%3/sec) - %4</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>MB</source>
-        <translation></translation>
+        <source>Download directory (%1) couldn&apos;t be created.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -800,6 +963,62 @@ Do you want to reload all pages?</source>
             <numerusform>%n 下载</numerusform>
         </translation>
     </message>
+    <message>
+        <source>There are %1 downloads in progress
+Do you want to quit anyway?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message numerus="yes">
+        <source>%n minutes remaining</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%n seconds remaining</source>
+        <translation type="unfinished">
+            <numerusform></numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>bytes</source>
+        <translation type="unfinished">字节</translation>
+    </message>
+    <message>
+        <source>kB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>MB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>GB</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>FileAccessReply</name>
+    <message>
+        <source>No Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error opening: %1: No such file or directory</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to read %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Contents of %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 KB</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>HistoryDialog</name>
@@ -871,11 +1090,34 @@ Do you want to reload all pages?</source>
         </translation>
     </message>
 </context>
+<context>
+    <name>JavaScriptAroraObject</name>
+    <message>
+        <source>Welcome to Arora!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Arora Start</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search!</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search results provided by</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Arora</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>LanguageManager</name>
     <message>
         <source>Default</source>
-        <translation>缺省</translation>
+        <translation type="obsolete">缺省</translation>
     </message>
     <message>
         <source>Choose language</source>
@@ -885,6 +1127,10 @@ Do you want to reload all pages?</source>
         <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
         <translation>&lt;p&gt;你可以运行在其它语言环境下&lt;br&gt;而不采用操作系统所缺省的语言环境&lt;/p&gt;&lt;p&gt;请选择应该使用的语言环境&lt;/p&gt;</translation>
     </message>
+    <message>
+        <source>No translation files are installed.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NetworkAccessManager</name>
@@ -904,48 +1150,115 @@ Do you want to reload all pages?</source>
 %2
 
 Do you want to ignore these errors?</source>
-        <translation>SSL 错误：%1%2希望忽略该错误吗？</translation>
+        <translation type="obsolete">SSL 错误：%1%2希望忽略该错误吗？</translation>
     </message>
     <message>
         <source>Do you want to accept all these certificates?</source>
-        <translation>确认接受所有证书吗？</translation>
+        <translation type="obsolete">确认接受所有证书吗？</translation>
+    </message>
+    <message>
+        <source> - SSL Errors</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;
+
+Do you want to ignore these errors?&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Issuer: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not valid before: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Valid until: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Alternate Names:</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>NetworkMonitor</name>
     <message>
         <source>Name</source>
-        <translation type="unfinished">名字</translation>
-    </message>
-    <message>
-        <source>Value</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">名字</translation>
     </message>
 </context>
 <context>
     <name>NetworkMonitorDialog</name>
-    <message>
-        <source>Network Monitor</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Network Requests</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Request Headers</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Response Headers</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Remove</source>
-        <translation type="unfinished">移除(&amp;R)</translation>
+        <translation type="obsolete">移除(&amp;R)</translation>
+    </message>
+</context>
+<context>
+    <name>OpenSearchDialog</name>
+    <message>
+        <source>Open File</source>
+        <translation type="unfinished">打开文件</translation>
     </message>
     <message>
-        <source>Remove &amp;All Requests</source>
+        <source>OpenSearch</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>You must have at least one search engine in here.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OpenSearch Manager</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Restore Defaults</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Add</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&amp;Close</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSearchEngineModel</name>
+    <message>
+        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>OpenSearchManager</name>
+    <message>
+        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -985,10 +1298,6 @@ Do you want to ignore these errors?</source>
         <source>Proxy Authentication</source>
         <translation>代理验证</translation>
     </message>
-    <message>
-        <source>ICON</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Connect to proxy</source>
         <translation>连接到代理</translation>
@@ -1012,60 +1321,36 @@ Do you want to ignore these errors?</source>
         <source>Unknown title</source>
         <translation>未知文件</translation>
     </message>
+    <message>
+        <source>The file is not an OpenSearch 1.1 file.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RequestModel</name>
-    <message>
-        <source>Redirect: %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Method</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Address</source>
-        <translation type="unfinished">地址</translation>
-    </message>
-    <message>
-        <source>Response</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Length</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Content Type</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Info</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">地址</translation>
     </message>
 </context>
 <context>
     <name>SearchBanner</name>
     <message>
         <source>Form</source>
-        <translation>表单</translation>
+        <translation type="obsolete">表单</translation>
     </message>
     <message>
         <source>TextLabel</source>
-        <translation>文本标签</translation>
-    </message>
-    <message>
-        <source>&lt;</source>
-        <translation></translation>
-    </message>
-    <message>
-        <source>&gt;</source>
-        <translation></translation>
+        <translation type="obsolete">文本标签</translation>
     </message>
     <message>
         <source>Done</source>
         <translation>完成</translation>
     </message>
+    <message>
+        <source>Highlight All</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
@@ -1146,7 +1431,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>In a tab in the current window</source>
-        <translation>在当前窗口的标签中</translation>
+        <translation type="obsolete">在当前窗口的标签中</translation>
     </message>
     <message>
         <source>In a new window</source>
@@ -1172,10 +1457,6 @@ Do you want to ignore these errors?</source>
         <source>Standard font:</source>
         <translation>标准字体：</translation>
     </message>
-    <message>
-        <source>Times 16</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Select...</source>
         <translation>选择...</translation>
@@ -1184,10 +1465,6 @@ Do you want to ignore these errors?</source>
         <source>Fixed-width font:</source>
         <translation>定宽字体：</translation>
     </message>
-    <message>
-        <source>Courier 13</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Privacy</source>
         <translation>隐私</translation>
@@ -1262,7 +1539,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>Confirm when closing multiple tabs</source>
-        <translation>关闭多个标签时进行确认</translation>
+        <translation type="obsolete">关闭多个标签时进行确认</translation>
     </message>
     <message>
         <source>Proxy</source>
@@ -1280,10 +1557,6 @@ Do you want to ignore these errors?</source>
         <source>Socks5</source>
         <translation></translation>
     </message>
-    <message>
-        <source>Http</source>
-        <translation></translation>
-    </message>
     <message>
         <source>Host name:</source>
         <translation>主机名：</translation>
@@ -1312,6 +1585,85 @@ Do you want to ignore these errors?</source>
         <source>Show only one close button instead of one for each tab</source>
         <translation>只显示一个关闭按钮，而不是在每个标签上都显示一个关闭按钮</translation>
     </message>
+    <message>
+        <source>Preferred languages for viewing webpages in:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Block Popup Windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Opening links</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Links that want to open in a new window:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In a new selected tab in the current window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In a new tab in the current window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In the current tab</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Http (Secure)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Http (Transparent)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use ClickToFlash on flash plugins</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Filter Tracking Cookies</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Confirm when closing multiple tabs or windows</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Quit the application when last tab is closed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable network cache</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Maximum Size:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> MB</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>SettingsDialog</name>
+    <message>
+        <source>Restart required</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SourceViewer</name>
@@ -1329,7 +1681,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>Source of Page </source>
-        <translation>页面源码</translation>
+        <translation type="obsolete">页面源码</translation>
     </message>
     <message>
         <source>&amp;View</source>
@@ -1339,6 +1691,10 @@ Do you want to ignore these errors?</source>
         <source>&amp;Wrap lines</source>
         <translation>折叠行(&amp;W)</translation>
     </message>
+    <message>
+        <source>Source of Page %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TabBar</name>
@@ -1352,7 +1708,7 @@ Do you want to ignore these errors?</source>
     </message>
     <message>
         <source>New &amp;Tab</source>
-        <translation>新标签页(&amp;T)</translation>
+        <translation type="obsolete">新标签页(&amp;T)</translation>
     </message>
     <message>
         <source>Duplicate Tab</source>
@@ -1419,6 +1775,30 @@ Do you really want to close this page?
         <source>Ctrl-[</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Saved Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Loading...</source>
+        <translation type="unfinished">加载...</translation>
+    </message>
+    <message>
+        <source>Loading %1% (%2 %3)...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Finished loading</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to load</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bookmark All Tabs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ToolbarSearch</name>
@@ -1432,7 +1812,19 @@ Do you really want to close this page?
     </message>
     <message>
         <source>Clear Recent Searches</source>
-        <translation>清除最近搜索</translation>
+        <translation type="unfinished">清除最近搜索</translation>
+    </message>
+    <message>
+        <source>Suggestions</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add &apos;%1&apos;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Configure Search Engines...</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -1451,7 +1843,7 @@ Do you really want to close this page?
     </message>
     <message>
         <source>If the address is correct, try to check the network connection.</source>
-        <translation>如果地址正确，那么请检查网络是否连接。</translation>
+        <translation type="obsolete">如果地址正确，那么请检查网络是否连接。</translation>
     </message>
     <message>
         <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
@@ -1461,6 +1853,18 @@ Do you really want to close this page?
         <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>If the address is correct, try checking the network connection.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Resending POST request</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WebView</name>
@@ -1508,6 +1912,38 @@ Do you really want to close this page?
         <source>Loading...</source>
         <translation>加载...</translation>
     </message>
+    <message>
+        <source>Search with...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Add to the toolbar search</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Method not supported</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 method is not supported.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Search engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Choose the desired search engine</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Engine name</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Type in a name for the engine</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WebViewSearch</name>
