@@ -64,6 +64,27 @@
 #define NETWORKACCESSMANAGER_H
 
 #include <qnetworkaccessmanager.h>
+#include <qnetworkproxy.h>
+#include <qsslconfiguration.h>
+
+class SchemeAccessHandler;
+
+#if QT_VERSION >= 0x040500
+class NetworkProxyFactory : public QNetworkProxyFactory
+{
+public:
+    NetworkProxyFactory();
+
+    void setHttpProxy(const QNetworkProxy &proxy);
+    void setGlobalProxy(const QNetworkProxy &proxy);
+
+    virtual QList<QNetworkProxy> queryProxy(const QNetworkProxyQuery &query = QNetworkProxyQuery());
+
+private:
+    QNetworkProxy m_httpProxy;
+    QNetworkProxy m_globalProxy;
+};
+#endif
 
 class NetworkAccessManager : public QNetworkAccessManager
 {
@@ -74,6 +95,7 @@ signals:
 
 public:
     NetworkAccessManager(QObject *parent = 0);
+    void setSchemeHandler(const QString &scheme, SchemeAccessHandler *handler);
 
 protected:
     QNetworkReply *createRequest(QNetworkAccessManager::Operation op, const QNetworkRequest &request, QIODevice *outgoingData = 0);
@@ -82,12 +104,20 @@ public slots:
     void loadSettings();
 
 private slots:
+    void privacyChanged(bool isPrivate);
     void authenticationRequired(QNetworkReply *reply, QAuthenticator *auth);
     void proxyAuthenticationRequired(const QNetworkProxy &proxy, QAuthenticator *auth);
 #ifndef QT_NO_OPENSSL
     void sslErrors(QNetworkReply *reply, const QList<QSslError> &error);
 #endif
 
+private:
+#ifndef QT_NO_OPENSSL
+    static QString certToFormattedString(QSslCertificate cert);
+#endif
+
+    QByteArray m_acceptLanguage;
+    QHash<QString, SchemeAccessHandler*> m_schemeHandlers;
 };
 
 #endif // NETWORKACCESSMANAGER_H
