@@ -62,23 +62,31 @@
 
 #include "settings.h"
 
+#include "acceptlanguagedialog.h"
 #include "browserapplication.h"
 #include "browsermainwindow.h"
 #include "cookiedialog.h"
 #include "cookieexceptionsdialog.h"
 #include "cookiejar.h"
-#include "history.h"
+#include "historymanager.h"
 #include "networkaccessmanager.h"
+#include "tabwidget.h"
+#include "webpluginfactory.h"
+#include "webpage.h"
 #include "webview.h"
 
 #include <qdesktopservices.h>
 #include <qfile.h>
 #include <qfontdialog.h>
 #include <qmetaobject.h>
+#include <qmessagebox.h>
 #include <qsettings.h>
 
 SettingsDialog::SettingsDialog(QWidget *parent)
     : QDialog(parent)
+#if QT_VERSION >= 0x040500
+    , m_cacheEnabled(false)
+#endif
 {
     setupUi(this);
     connect(exceptionsButton, SIGNAL(clicked()), this, SLOT(showExceptions()));
@@ -86,9 +94,15 @@ SettingsDialog::SettingsDialog(QWidget *parent)
     connect(cookiesButton, SIGNAL(clicked()), this, SLOT(showCookies()));
     connect(standardFontButton, SIGNAL(clicked()), this, SLOT(chooseFont()));
     connect(fixedFontButton, SIGNAL(clicked()), this, SLOT(chooseFixedFont()));
+    connect(languageButton, SIGNAL(clicked()), this, SLOT(chooseAcceptLanguage()));
 
 #if QT_VERSION < 0x040500
     oneCloseButton->setVisible(false); // no other mode than one close button with qt <4.5
+    networkCache->setVisible(false);
+#else
+    // As network cache has too many bugs in 4.5.1, do not allow to enable it.
+    if (QLatin1String(qVersion()) == QLatin1String("4.5.1"))
+        networkCache->setVisible(false);
 #endif
     loadDefaults();
     loadFromSettings();
@@ -99,26 +113,29 @@ void SettingsDialog::loadDefaults()
     QWebSettings *defaultSettings = QWebSettings::globalSettings();
     QString standardFontFamily = defaultSettings->fontFamily(QWebSettings::StandardFont);
     int standardFontSize = defaultSettings->fontSize(QWebSettings::DefaultFontSize);
-    standardFont = QFont(standardFontFamily, standardFontSize);
-    standardLabel->setText(QString(QLatin1String("%1 %2")).arg(standardFont.family()).arg(standardFont.pointSize()));
+    m_standardFont = QFont(standardFontFamily, standardFontSize);
+    standardLabel->setText(QString(QLatin1String("%1 %2")).arg(m_standardFont.family()).arg(m_standardFont.pointSize()));
 
     QString fixedFontFamily = defaultSettings->fontFamily(QWebSettings::FixedFont);
     int fixedFontSize = defaultSettings->fontSize(QWebSettings::DefaultFixedFontSize);
-    fixedFont = QFont(fixedFontFamily, fixedFontSize);
-    fixedLabel->setText(QString(QLatin1String("%1 %2")).arg(fixedFont.family()).arg(fixedFont.pointSize()));
+    m_fixedFont = QFont(fixedFontFamily, fixedFontSize);
+    fixedLabel->setText(QString(QLatin1String("%1 %2")).arg(m_fixedFont.family()).arg(m_fixedFont.pointSize()));
 
     downloadsLocation->setText(QDesktopServices::storageLocation(QDesktopServices::DesktopLocation));
 
+    blockPopupWindows->setChecked(!defaultSettings->testAttribute(QWebSettings::JavascriptCanOpenWindows));
     enableJavascript->setChecked(defaultSettings->testAttribute(QWebSettings::JavascriptEnabled));
     enablePlugins->setChecked(defaultSettings->testAttribute(QWebSettings::PluginsEnabled));
     enableImages->setChecked(defaultSettings->testAttribute(QWebSettings::AutoLoadImages));
+    clickToFlash->setChecked(false);
+    filterTrackingCookiesCheckbox->setChecked(true);
 }
 
 void SettingsDialog::loadFromSettings()
 {
     QSettings settings;
     settings.beginGroup(QLatin1String("MainWindow"));
-    QString defaultHome = QLatin1String("http://www.arora-browser.org");
+    QString defaultHome = QLatin1String("about:home");
     homeLineEdit->setText(settings.value(QLatin1String("home"), defaultHome).toString());
     startupBehavior->setCurrentIndex(settings.value(QLatin1String("startupBehavior"), 0).toInt());
     settings.endGroup();
@@ -140,31 +157,32 @@ void SettingsDialog::loadFromSettings()
     expireHistory->setCurrentIndex(idx);
     settings.endGroup();
 
+    settings.beginGroup(QLatin1String("urlloading"));
+    bool search = settings.value(QLatin1String("searchEngineFallback"), false).toBool();
+    searchEngineFallback->setChecked(search);
+    settings.endGroup();
+
     settings.beginGroup(QLatin1String("downloadmanager"));
     bool alwaysPromptForFileName = settings.value(QLatin1String("alwaysPromptForFileName"), false).toBool();
-    if (alwaysPromptForFileName)
-        downloadAsk->setChecked(true);
+    downloadAsk->setChecked(alwaysPromptForFileName);
     QString downloadDirectory = settings.value(QLatin1String("downloadDirectory"), downloadsLocation->text()).toString();
     downloadsLocation->setText(downloadDirectory);
     settings.endGroup();
 
-    settings.beginGroup(QLatin1String("general"));
-    openLinksIn->setCurrentIndex(settings.value(QLatin1String("openLinksIn"), openLinksIn->currentIndex()).toInt());
-
-    settings.endGroup();
-
     // Appearance
     settings.beginGroup(QLatin1String("websettings"));
-    fixedFont = qVariantValue<QFont>(settings.value(QLatin1String("fixedFont"), fixedFont));
-    standardFont = qVariantValue<QFont>(settings.value(QLatin1String("standardFont"), standardFont));
+    m_fixedFont = qVariantValue<QFont>(settings.value(QLatin1String("fixedFont"), m_fixedFont));
+    m_standardFont = qVariantValue<QFont>(settings.value(QLatin1String("standardFont"), m_standardFont));
 
-    standardLabel->setText(QString(QLatin1String("%1 %2")).arg(standardFont.family()).arg(standardFont.pointSize()));
-    fixedLabel->setText(QString(QLatin1String("%1 %2")).arg(fixedFont.family()).arg(fixedFont.pointSize()));
+    standardLabel->setText(QString(QLatin1String("%1 %2")).arg(m_standardFont.family()).arg(m_standardFont.pointSize()));
+    fixedLabel->setText(QString(QLatin1String("%1 %2")).arg(m_fixedFont.family()).arg(m_fixedFont.pointSize()));
 
+    blockPopupWindows->setChecked(settings.value(QLatin1String("blockPopupWindows"), blockPopupWindows->isChecked()).toBool());
     enableJavascript->setChecked(settings.value(QLatin1String("enableJavascript"), enableJavascript->isChecked()).toBool());
     enablePlugins->setChecked(settings.value(QLatin1String("enablePlugins"), enablePlugins->isChecked()).toBool());
     enableImages->setChecked(settings.value(QLatin1String("enableImages"), enableImages->isChecked()).toBool());
-    userStyleSheet->setText(settings.value(QLatin1String("userStyleSheet")).toUrl().toString());
+    userStyleSheet->setText(QString::fromUtf8(settings.value(QLatin1String("userStyleSheet")).toUrl().toEncoded()));
+    clickToFlash->setChecked(settings.value(QLatin1String("enableClickToFlash"), clickToFlash->isChecked()).toBool());
     settings.endGroup();
 
     // Privacy
@@ -204,8 +222,17 @@ void SettingsDialog::loadFromSettings()
         keepUntilCombo->setCurrentIndex(2);
         break;
     }
+    filterTrackingCookiesCheckbox->setChecked(settings.value(QLatin1String("filterTrackingCookies"), true).toBool());
     settings.endGroup();
 
+#if QT_VERSION >= 0x040500
+    // Network
+    settings.beginGroup(QLatin1String("network"));
+    m_cacheEnabled = settings.value(QLatin1String("cacheEnabled"), true).toBool();
+    networkCache->setChecked(m_cacheEnabled);
+    networkCacheMaximumSizeSpinBox->setValue(settings.value(QLatin1String("maximumCacheSize"), 50).toInt());
+    settings.endGroup();
+#endif
 
     // Proxy
     settings.beginGroup(QLatin1String("proxy"));
@@ -224,6 +251,9 @@ void SettingsDialog::loadFromSettings()
 #if QT_VERSION >= 0x040500
     oneCloseButton->setChecked(settings.value(QLatin1String("oneCloseButton"),false).toBool());
 #endif
+    quitAsLastTabClosed->setChecked(settings.value(QLatin1String("quitAsLastTabClosed"), true).toBool());
+    openTargetBlankLinksIn->setCurrentIndex(settings.value(QLatin1String("openTargetBlankLinksIn"), TabWidget::NewSelectedTab).toInt());
+    openLinksFromAppsIn->setCurrentIndex(settings.value(QLatin1String("openLinksFromAppsIn"), TabWidget::NewSelectedTab).toInt());
     settings.endGroup();
 }
 
@@ -240,10 +270,6 @@ void SettingsDialog::saveToSettings()
     settings.setValue(QLatin1String("downloadDirectory"), downloadsLocation->text());
     settings.endGroup();
 
-    settings.beginGroup(QLatin1String("general"));
-    settings.setValue(QLatin1String("openLinksIn"), openLinksIn->currentIndex());
-    settings.endGroup();
-
     settings.beginGroup(QLatin1String("history"));
     int historyExpire = expireHistory->currentIndex();
     int idx = -1;
@@ -259,10 +285,16 @@ void SettingsDialog::saveToSettings()
     settings.setValue(QLatin1String("historyLimit"), idx);
     settings.endGroup();
 
+    settings.beginGroup(QLatin1String("urlloading"));
+    settings.setValue(QLatin1String("searchEngineFallback"), searchEngineFallback->isChecked());
+    settings.endGroup();
+
     // Appearance
     settings.beginGroup(QLatin1String("websettings"));
-    settings.setValue(QLatin1String("fixedFont"), fixedFont);
-    settings.setValue(QLatin1String("standardFont"), standardFont);
+    settings.setValue(QLatin1String("fixedFont"), m_fixedFont);
+    settings.setValue(QLatin1String("standardFont"), m_standardFont);
+
+    settings.setValue(QLatin1String("blockPopupWindows"), blockPopupWindows->isChecked());
     settings.setValue(QLatin1String("enableJavascript"), enableJavascript->isChecked());
     settings.setValue(QLatin1String("enablePlugins"), enablePlugins->isChecked());
     settings.setValue(QLatin1String("enableImages"), enableImages->isChecked());
@@ -270,28 +302,29 @@ void SettingsDialog::saveToSettings()
     if (QFile::exists(userStyleSheetString))
         settings.setValue(QLatin1String("userStyleSheet"), QUrl::fromLocalFile(userStyleSheetString));
     else
-        settings.setValue(QLatin1String("userStyleSheet"), QUrl(userStyleSheetString));
+        settings.setValue(QLatin1String("userStyleSheet"), QUrl::fromEncoded(userStyleSheetString.toUtf8()));
+    settings.setValue(QLatin1String("enableClickToFlash"), clickToFlash->isChecked());
     settings.endGroup();
 
-    //Privacy
+    // Privacy
     settings.beginGroup(QLatin1String("cookies"));
-
-    CookieJar::KeepPolicy keepCookies;
+    CookieJar::AcceptPolicy acceptCookies;
     switch (acceptCombo->currentIndex()) {
     default:
     case 0:
-        keepCookies = CookieJar::KeepUntilExpire;
+        acceptCookies = CookieJar::AcceptAlways;
         break;
     case 1:
-        keepCookies = CookieJar::KeepUntilExit;
+        acceptCookies = CookieJar::AcceptNever;
         break;
     case 2:
-        keepCookies = CookieJar::KeepUntilTimeLimit;
+        acceptCookies = CookieJar::AcceptOnlyFromSitesNavigatedTo;
         break;
     }
+
     CookieJar *jar = BrowserApplication::cookieJar();
     QMetaEnum acceptPolicyEnum = jar->staticMetaObject.enumerator(jar->staticMetaObject.indexOfEnumerator("AcceptPolicy"));
-    settings.setValue(QLatin1String("acceptCookies"), QLatin1String(acceptPolicyEnum.valueToKey(keepCookies)));
+    settings.setValue(QLatin1String("acceptCookies"), QLatin1String(acceptPolicyEnum.valueToKey(acceptCookies)));
 
     CookieJar::KeepPolicy keepPolicy;
     switch (keepUntilCombo->currentIndex()) {
@@ -309,9 +342,17 @@ void SettingsDialog::saveToSettings()
 
     QMetaEnum keepPolicyEnum = jar->staticMetaObject.enumerator(jar->staticMetaObject.indexOfEnumerator("KeepPolicy"));
     settings.setValue(QLatin1String("keepCookiesUntil"), QLatin1String(keepPolicyEnum.valueToKey(keepPolicy)));
-
+    settings.setValue(QLatin1String("filterTrackingCookies"), filterTrackingCookiesCheckbox->isChecked());
     settings.endGroup();
 
+#if QT_VERSION >= 0x040500
+    // Network
+    settings.beginGroup(QLatin1String("network"));
+    settings.setValue(QLatin1String("cacheEnabled"), networkCache->isChecked());
+    settings.setValue(QLatin1String("maximumCacheSize"), networkCacheMaximumSizeSpinBox->value());
+    settings.endGroup();
+#endif
+
     // proxy
     settings.beginGroup(QLatin1String("proxy"));
     settings.setValue(QLatin1String("enabled"), proxySupport->isChecked());
@@ -329,38 +370,56 @@ void SettingsDialog::saveToSettings()
 #if QT_VERSION >= 0x040500
     settings.setValue(QLatin1String("oneCloseButton"), oneCloseButton->isChecked());
 #endif
+    settings.setValue(QLatin1String("quitAsLastTabClosed"), quitAsLastTabClosed->isChecked());
+    settings.setValue(QLatin1String("openTargetBlankLinksIn"), openTargetBlankLinksIn->currentIndex());
+    settings.setValue(QLatin1String("openLinksFromAppsIn"), openLinksFromAppsIn->currentIndex());
     settings.endGroup();
 
     BrowserApplication::instance()->loadSettings();
     BrowserApplication::networkAccessManager()->loadSettings();
     BrowserApplication::cookieJar()->loadSettings();
     BrowserApplication::historyManager()->loadSettings();
+
+    WebPage::webPluginFactory()->refreshPlugins();
+
+    QList<BrowserMainWindow*> list = BrowserApplication::instance()->mainWindows();
+    foreach (BrowserMainWindow *mainWindow, list) {
+        mainWindow->tabWidget()->loadSettings();
+    }
 }
 
 void SettingsDialog::accept()
 {
     saveToSettings();
+#if QT_VERSION >= 0x040500
+    // Due to a bug in Qt <= 4.5.1, enabling/disabling cache requires the browser to be restarted.
+    if (QLatin1String(qVersion()) <= QLatin1String("4.5.1") && networkCache->isChecked() != m_cacheEnabled) {
+        QMessageBox::information(this, tr("Restart required"),
+                                 tr("The network cache configuration has changed. "
+                                    "So that it can be taken into account, the browser has to be restarted."));
+    }
+#endif
     QDialog::accept();
 }
 
 void SettingsDialog::showCookies()
 {
-    CookieDialog *dialog = new CookieDialog(BrowserApplication::cookieJar(), this);
-    dialog->exec();
+    CookieDialog dialog(BrowserApplication::cookieJar(), this);
+    dialog.exec();
 }
 
 void SettingsDialog::showExceptions()
 {
-    CookieExceptionsDialog *dialog = new CookieExceptionsDialog(BrowserApplication::cookieJar(), this);
-    dialog->exec();
+    CookieExceptionsDialog dialog(BrowserApplication::cookieJar(), this);
+    dialog.exec();
 }
 
 void SettingsDialog::chooseFont()
 {
     bool ok;
-    QFont font = QFontDialog::getFont(&ok, standardFont, this);
+    QFont font = QFontDialog::getFont(&ok, m_standardFont, this);
     if (ok) {
-        standardFont = font;
+        m_standardFont = font;
         standardLabel->setText(QString(QLatin1String("%1 %2")).arg(font.family()).arg(font.pointSize()));
     }
 }
@@ -368,9 +427,9 @@ void SettingsDialog::chooseFont()
 void SettingsDialog::chooseFixedFont()
 {
     bool ok;
-    QFont font = QFontDialog::getFont(&ok, fixedFont, this);
+    QFont font = QFontDialog::getFont(&ok, m_fixedFont, this);
     if (ok) {
-        fixedFont = font;
+        m_fixedFont = font;
         fixedLabel->setText(QString(QLatin1String("%1 %2")).arg(font.family()).arg(font.pointSize()));
     }
 }
@@ -380,6 +439,12 @@ void SettingsDialog::setHomeToCurrentPage()
     BrowserMainWindow *mw = static_cast<BrowserMainWindow*>(parent());
     WebView *webView = mw->currentTab();
     if (webView)
-        homeLineEdit->setText(webView->url().toString());
+        homeLineEdit->setText(QString::fromUtf8(webView->url().toEncoded()));
+}
+
+void SettingsDialog::chooseAcceptLanguage()
+{
+    AcceptLanguageDialog dialog;
+    dialog.exec();
 }
 
