@@ -62,6 +62,8 @@
 
 #include "tabbar.h"
 
+#include "tabwidget.h"
+
 #include <qaction.h>
 #include <qapplication.h>
 #include <qclipboard.h>
@@ -96,8 +98,8 @@ TabBar::TabBar(QWidget *parent)
             this, SLOT(contextMenuRequested(const QPoint &)));
 
     QString alt = QLatin1String("Ctrl+%1");
-    for (int i = 0; i < 10; ++i) {
-        int key = i == 9 ? 0 : i + 1;
+    for (int i = 0; i < 9; ++i) {
+        int key = i + 1;
         TabShortcut *tabShortCut = new TabShortcut(i, alt.arg(key), this);
         connect(tabShortCut, SIGNAL(activated()), this, SLOT(selectTabAction()));
     }
@@ -159,7 +161,11 @@ void TabBar::selectTabAction()
 void TabBar::contextMenuRequested(const QPoint &position)
 {
     QMenu menu;
-    menu.addAction(tr("New &Tab"), this, SIGNAL(newTab()), QKeySequence::AddTab);
+    TabWidget *tabWidget = qobject_cast<TabWidget*>(parentWidget());
+    if (!tabWidget)
+        return;
+
+    menu.addAction(tabWidget->newTabAction());
     int index = tabAt(position);
     if (-1 != index) {
         QAction *action = menu.addAction(tr("Duplicate Tab"),
@@ -185,6 +191,8 @@ void TabBar::contextMenuRequested(const QPoint &position)
         menu.addSeparator();
     }
     menu.addAction(tr("Reload All Tabs"), this, SIGNAL(reloadAllTabs()));
+    menu.addSeparator();
+    menu.addAction(tabWidget->bookmarkTabsAction());
     menu.exec(QCursor::pos());
 }
 
@@ -215,8 +223,10 @@ void TabBar::closeOtherTabs()
 void TabBar::mouseDoubleClickEvent(QMouseEvent *event)
 {
     if (!childAt(event->pos())
-        // Remove the line below when QTabWidget does not have a one pixel frame
-        && event->pos().y() < (y() + height())) {
+#if QT_VERSION < 0x040500
+        && event->pos().y() < (y() + height())
+#endif
+        && event->button() == Qt::LeftButton) {
         emit newTab();
         return;
     }
@@ -298,6 +308,27 @@ void TabBar::dropEvent(QDropEvent *event)
     }
     QTabBar::dropEvent(event);
 }
+#else
+void TabBar::dragEnterEvent(QDragEnterEvent *event)
+{
+    const QMimeData *mimeData = event->mimeData();
+    if (mimeData->hasUrls())
+        event->acceptProposedAction();
+
+    QTabBar::dragEnterEvent(event);
+}
+
+void TabBar::dropEvent(QDropEvent *event)
+{
+    const QMimeData *mimeData = event->mimeData();
+    QUrl url = mimeData->urls().at(0);
+    if (url.isValid()) {
+        event->acceptProposedAction();
+        loadUrl(url, TabWidget::NewSelectedTab);
+    }
+
+    QTabBar::dropEvent(event);
+}
 #endif
 
 QSize TabBar::tabSizeHint(int index) const
@@ -330,7 +361,9 @@ void TabBar::tabRemoved(int position)
 void TabBar::updateVisibility()
 {
     setVisible((count()) > 1 || m_showTabBarWhenOneTab);
-    m_viewTabBarAction->setEnabled(count() == 1);
+    bool enabled = (count() == 1);
+    if (m_viewTabBarAction->isEnabled() != enabled)
+        m_viewTabBarAction->setEnabled(enabled);
     updateViewToolBarAction();
 }
 
