@@ -62,17 +62,27 @@
 
 #include "tabwidget.h"
 
+#include "addbookmarkdialog.h"
+#include "bookmarknode.h"
+#include "bookmarksmanager.h"
+#include "bookmarksmodel.h"
 #include "browserapplication.h"
 #include "browsermainwindow.h"
 #include "history.h"
-#include "tabbar.h"
+#include "historycompleter.h"
+#include "historymanager.h"
 #include "locationbar.h"
+#include "opensearchengine.h"
+#include "opensearchmanager.h"
+#include "tabbar.h"
 #include "toolbarsearch.h"
 #include "webactionmapper.h"
+#include "webpage.h"
 #include "webview.h"
 #include "webviewsearch.h"
 
 #include <qcompleter.h>
+#include <qdir.h>
 #include <qevent.h>
 #include <qlistview.h>
 #include <qmenu.h>
@@ -85,14 +95,18 @@
 
 #include <qdebug.h>
 
+//#define USERMODIFIEDBEHAVIOR_DEBUG
+
 TabWidget::TabWidget(QWidget *parent)
     : QTabWidget(parent)
     , m_recentlyClosedTabsAction(0)
     , m_newTabAction(0)
     , m_closeTabAction(0)
+    , m_bookmarkTabsAction(0)
     , m_nextTabAction(0)
     , m_previousTabAction(0)
     , m_recentlyClosedTabsMenu(0)
+    , m_swappedDelayedWidget(false)
     , m_lineEditCompleter(0)
     , m_lineEdits(0)
     , m_tabBar(new TabBar(this))
@@ -101,8 +115,8 @@ TabWidget::TabWidget(QWidget *parent)
 
     new QShortcut(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_T), this, SLOT(openLastTab()));
 
-    connect(m_tabBar, SIGNAL(loadUrl(const QUrl&, TabWidget::Tab)),
-            this, SLOT(loadUrl(const QUrl&, TabWidget::Tab)));
+    connect(m_tabBar, SIGNAL(loadUrl(const QUrl&, TabWidget::OpenUrlIn)),
+            this, SLOT(loadUrl(const QUrl&, TabWidget::OpenUrlIn)));
     connect(m_tabBar, SIGNAL(newTab()), this, SLOT(newTab()));
     connect(m_tabBar, SIGNAL(closeTab(int)), this, SLOT(closeTab(int)));
     connect(m_tabBar, SIGNAL(cloneTab(int)), this, SLOT(cloneTab(int)));
@@ -120,48 +134,37 @@ TabWidget::TabWidget(QWidget *parent)
 #endif
 
     // Actions
-    m_newTabAction = new QAction(tr("New &Tab"), this);
+    m_newTabAction = new QAction(this);
     m_newTabAction->setShortcuts(QKeySequence::AddTab);
     connect(m_newTabAction, SIGNAL(triggered()), this, SLOT(newTab()));
 
-    m_closeTabAction = new QAction(tr("&Close Tab"), this);
+    m_closeTabAction = new QAction(this);
     m_closeTabAction->setShortcuts(QKeySequence::Close);
     connect(m_closeTabAction, SIGNAL(triggered()), this, SLOT(closeTab()));
 
-#if QT_VERSION >= 0x040500
+    m_bookmarkTabsAction = new QAction(this);
+    connect(m_bookmarkTabsAction, SIGNAL(triggered()), this, SLOT(bookmarkTabs()));
+
+    m_newTabAction->setIcon(QIcon(QLatin1String(":graphics/addtab.png")));
+    m_newTabAction->setIconVisibleInMenu(false);
+
     QSettings settings;
+#if QT_VERSION >= 0x040500
     settings.beginGroup(QLatin1String("tabs"));
     bool oneCloseButton = settings.value(QLatin1String("oneCloseButton"), false).toBool();
     if (oneCloseButton) {
 #endif
         // With Qt < 4.5 do this always, with >=4.5 only if enabled.
-        m_newTabAction->setIcon(QIcon(QLatin1String(":addtab.png")));
-        m_newTabAction->setIconVisibleInMenu(false);
-
-        m_closeTabAction->setIcon(QIcon(QLatin1String(":closetab.png")));
+        m_closeTabAction->setIcon(QIcon(QLatin1String(":graphics/closetab.png")));
         m_closeTabAction->setIconVisibleInMenu(false);
 #if QT_VERSION >= 0x040500
     }
 #endif
 
-    m_nextTabAction = new QAction(tr("Show Next Tab"), this);
-    QList<QKeySequence> shortcuts;
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_BraceRight));
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_PageDown));
-    shortcuts.append(tr("Ctrl-]"));
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_Less));
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_Tab));
-    m_nextTabAction->setShortcuts(shortcuts);
+    m_nextTabAction = new QAction(this);
     connect(m_nextTabAction, SIGNAL(triggered()), this, SLOT(nextTab()));
 
-    m_previousTabAction = new QAction(tr("Show Previous Tab"), this);
-    shortcuts.clear();
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_BraceLeft));
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_PageUp));
-    shortcuts.append(tr("Ctrl-["));
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_Greater));
-    shortcuts.append(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Tab));
-    m_previousTabAction->setShortcuts(shortcuts);
+    m_previousTabAction = new QAction(this);
     connect(m_previousTabAction, SIGNAL(triggered()), this, SLOT(previousTab()));
 
     m_recentlyClosedTabsMenu = new QMenu(this);
@@ -169,33 +172,35 @@ TabWidget::TabWidget(QWidget *parent)
             this, SLOT(aboutToShowRecentTabsMenu()));
     connect(m_recentlyClosedTabsMenu, SIGNAL(triggered(QAction *)),
             this, SLOT(aboutToShowRecentTriggeredAction(QAction *)));
-    m_recentlyClosedTabsAction = new QAction(tr("Recently Closed Tabs"), this);
+    m_recentlyClosedTabsAction = new QAction(this);
     m_recentlyClosedTabsAction->setMenu(m_recentlyClosedTabsMenu);
     m_recentlyClosedTabsAction->setEnabled(false);
 
+    bool newTabButtonInRightCorner = settings.value(QLatin1String("newTabButtonInRightCorner"), true).toBool();
+#ifndef Q_WS_MAC // can't seem to figure out the background color :(
+    QToolButton *addTabButton = new QToolButton(this);
+    addTabButton->setDefaultAction(m_newTabAction);
+    addTabButton->setAutoRaise(true);
+    addTabButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
+    setCornerWidget(addTabButton, newTabButtonInRightCorner ? Qt::TopRightCorner : Qt::TopLeftCorner);
+#endif
+
 #if QT_VERSION >= 0x040500
     if (oneCloseButton) {
 #endif
         // corner buttons
         // With Qt < 4.5 do this always, with >=4.5 only if enabled.
-        QToolButton *addTabButton = new QToolButton(this);
-        addTabButton->setDefaultAction(m_newTabAction);
-        addTabButton->setAutoRaise(true);
-        addTabButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
-        setCornerWidget(addTabButton, Qt::TopLeftCorner);
-
         QToolButton *closeTabButton = new QToolButton(this);
         closeTabButton->setDefaultAction(m_closeTabAction);
         closeTabButton->setAutoRaise(true);
         closeTabButton->setToolButtonStyle(Qt::ToolButtonIconOnly);
-        setCornerWidget(closeTabButton, Qt::TopRightCorner);
+        setCornerWidget(closeTabButton, newTabButtonInRightCorner ? Qt::TopLeftCorner : Qt::TopRightCorner);
 #if QT_VERSION >= 0x040500
     } else {
         m_tabBar->setTabsClosable(true);
 
         connect(m_tabBar, SIGNAL(tabCloseRequested(int)),
                 this, SLOT(closeTab(int)));
-        m_tabBar->setSelectionBehaviorOnRemove(QTabBar::SelectPreviousTab);
     }
 #endif
 
@@ -206,6 +211,9 @@ TabWidget::TabWidget(QWidget *parent)
 
     connect(BrowserApplication::historyManager(), SIGNAL(historyCleared()),
         this, SLOT(historyCleared()));
+
+    // Initialize Actions' labels
+    retranslate();
 }
 
 void TabWidget::historyCleared()
@@ -323,6 +331,11 @@ QAction *TabWidget::closeTabAction() const
     return m_closeTabAction;
 }
 
+QAction *TabWidget::bookmarkTabsAction() const
+{
+    return m_bookmarkTabsAction;
+}
+
 QAction *TabWidget::recentlyClosedTabsAction() const
 {
     return m_recentlyClosedTabsAction;
@@ -382,6 +395,7 @@ WebView *TabWidget::webView(int index) const
             if (giveBackFocus)
                 currentLocationBar->setFocus();
             that->setUpdatesEnabled(true);
+            that->m_swappedDelayedWidget = true;
             return currentWebView();
         }
     }
@@ -417,32 +431,16 @@ void TabWidget::newTab()
     makeNewTab(true);
 }
 
-BrowserMainWindow *TabWidget::mainWindow()
-{
-    QWidget *w = this->parentWidget();
-    while (w) {
-        if (BrowserMainWindow *mw = qobject_cast<BrowserMainWindow*>(w))
-            return mw;
-        w = w->parentWidget();
-    }
-    return 0;
-}
-
 WebView *TabWidget::makeNewTab(bool makeCurrent)
 {
-    if (!makeCurrent) {
-        QSettings settings;
-        settings.beginGroup(QLatin1String("tabs"));
-        makeCurrent = settings.value(QLatin1String("selectNewTabs"), false).toBool();
-    }
-
     // line edit
     LocationBar *locationBar = new LocationBar;
     if (!m_lineEditCompleter) {
         HistoryCompletionModel *completionModel = new HistoryCompletionModel(this);
         completionModel->setSourceModel(BrowserApplication::historyManager()->historyFilterModel());
-        m_lineEditCompleter = new QCompleter(completionModel, this);
-        connect(m_lineEditCompleter, SIGNAL(activated(QString)), mainWindow(), SLOT(loadPage(QString)));
+        m_lineEditCompleter = new HistoryCompleter(completionModel, this);
+        connect(m_lineEditCompleter, SIGNAL(activated(const QString &)),
+                this, SLOT(loadString(const QString &)));
         // Should this be in Qt by default?
         QAbstractItemView *popup = m_lineEditCompleter->popup();
         QListView *listView = qobject_cast<QListView*>(popup);
@@ -457,7 +455,9 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
     m_lineEdits->addWidget(locationBar);
     m_lineEdits->setSizePolicy(locationBar->sizePolicy());
 
-    QWidget::setTabOrder(locationBar, qFindChild<ToolbarSearch*>(mainWindow()));
+#ifndef AUTOTESTS
+    QWidget::setTabOrder(locationBar, qFindChild<ToolbarSearch*>(BrowserMainWindow::parentWindow(this)));
+#endif
 
     // optimization to delay creating the more expensive WebView, history, etc
     if (count() == 0) {
@@ -479,14 +479,18 @@ WebView *TabWidget::makeNewTab(bool makeCurrent)
     locationBar->setWebView(webView);
     connect(webView, SIGNAL(loadStarted()),
             this, SLOT(webViewLoadStarted()));
+    connect(webView, SIGNAL(loadProgress(int)),
+                this, SLOT(webViewLoadProgress(int)));
     connect(webView, SIGNAL(loadFinished(bool)),
-            this, SLOT(webViewLoadFinished()));
+            this, SLOT(webViewLoadFinished(bool)));
     connect(webView, SIGNAL(iconChanged()),
             this, SLOT(webViewIconChanged()));
     connect(webView, SIGNAL(titleChanged(const QString &)),
             this, SLOT(webViewTitleChanged(const QString &)));
     connect(webView, SIGNAL(urlChanged(const QUrl &)),
             this, SLOT(webViewUrlChanged(const QUrl &)));
+    connect(webView, SIGNAL(search(const QUrl&, TabWidget::OpenUrlIn)),
+            this, SLOT(loadUrl(const QUrl&, TabWidget::OpenUrlIn)));
     connect(webView->page(), SIGNAL(windowCloseRequested()),
             this, SLOT(windowCloseRequested()));
     connect(webView->page(), SIGNAL(printRequested(QWebFrame *)),
@@ -550,10 +554,35 @@ void TabWidget::reloadAllTabs()
     }
 }
 
+void TabWidget::bookmarkTabs()
+{
+    AddBookmarkDialog dialog;
+    dialog.setFolder(true);
+    dialog.setTitle(tr("Saved Tabs"));
+    dialog.exec();
+
+    BookmarkNode *folder = dialog.addedNode();
+    if (!folder)
+        return;
+
+    for (int i = 0; i < count(); ++i) {
+        WebView *tab = webView(i);
+        if (!tab)
+            continue;
+
+        QString title = tab->title();
+        QString url = QString::fromUtf8(tab->url().toEncoded());
+        BookmarkNode *bookmark = new BookmarkNode(BookmarkNode::Bookmark);
+        bookmark->url = url;
+        bookmark->title = title;
+        BrowserApplication::bookmarksManager()->addBookmark(folder, bookmark);
+    }
+}
+
 void TabWidget::lineEditReturnPressed()
 {
     if (QLineEdit *lineEdit = qobject_cast<QLineEdit*>(sender())) {
-        emit loadPage(lineEdit->text());
+        loadString(lineEdit->text());
         if (m_lineEdits->currentWidget() == lineEdit)
             currentWebView()->setFocus();
     }
@@ -562,11 +591,13 @@ void TabWidget::lineEditReturnPressed()
 void TabWidget::windowCloseRequested()
 {
     WebPage *webPage = qobject_cast<WebPage*>(sender());
+    if (!webPage)
+        return;
     WebView *webView = qobject_cast<WebView*>(webPage->view());
     int index = webViewIndex(webView);
     if (index >= 0) {
         if (count() == 1)
-            webView->webPage()->mainWindow()->close();
+            BrowserMainWindow::parentWindow(this)->close();
         else
             closeTab(index);
     }
@@ -635,7 +666,7 @@ void TabWidget::closeTab(int index)
     webViewWithSearch->deleteLater();
 
     emit tabsChanged();
-    if (hasFocus && count() > 0)
+    if (hasFocus && count() > 0 && currentWebView())
         currentWebView()->setFocus();
     if (count() == 0)
         emit lastTabClosed();
@@ -656,7 +687,8 @@ QLabel *TabWidget::animationLabel(int index, bool addMovie)
         loadingAnimation = new QLabel(this);
     }
     if (addMovie && !loadingAnimation->movie()) {
-        QMovie *movie = new QMovie(QLatin1String(":loading.gif"), QByteArray(), loadingAnimation);
+        QMovie *movie = new QMovie(QLatin1String(":graphics/loading.gif"), QByteArray(), loadingAnimation);
+        movie->setSpeed(50);
         loadingAnimation->setMovie(movie);
         movie->start();
     }
@@ -676,17 +708,38 @@ void TabWidget::webViewLoadStarted()
         if (label->movie())
             label->movie()->start();
 #else
-        QIcon icon(QLatin1String(":loading.gif"));
+        QIcon icon(QLatin1String(":graphics/loading.gif"));
         setTabIcon(index, icon);
 #endif
     }
+
+    if (index != currentIndex())
+        return;
+
+    emit showStatusBarMessage(tr("Loading..."));
 }
 
-void TabWidget::webViewLoadFinished()
+void TabWidget::webViewLoadProgress(int progress)
 {
-#if QT_VERSION >= 0x040500
     WebView *webView = qobject_cast<WebView*>(sender());
     int index = webViewIndex(webView);
+
+    if (index != currentIndex()
+        || index < 0)
+        return;
+
+    double totalBytes = (double) webView->webPage()->totalBytes() / 1024;
+
+    QString message = tr("Loading %1% (%2 %3)...").arg(progress).arg(totalBytes, 0, 'f', 2).arg(QLatin1String("kB"));
+    emit showStatusBarMessage(message);
+}
+
+void TabWidget::webViewLoadFinished(bool ok)
+{
+    WebView *webView = qobject_cast<WebView*>(sender());
+    int index = webViewIndex(webView);
+
+#if QT_VERSION >= 0x040500
     if (-1 != index) {
         QLabel *label = animationLabel(index, true);
         if (label->movie())
@@ -699,6 +752,14 @@ void TabWidget::webViewLoadFinished()
     }
 #endif
     webViewIconChanged();
+
+    if (index != currentIndex())
+        return;
+
+    if (ok)
+        emit showStatusBarMessage(tr("Finished loading"));
+    else
+        emit showStatusBarMessage(tr("Failed to load"));
 }
 
 void TabWidget::webViewIconChanged()
@@ -726,13 +787,14 @@ void TabWidget::webViewTitleChanged(const QString &title)
 {
     WebView *webView = qobject_cast<WebView*>(sender());
     int index = webViewIndex(webView);
-    if (-1 != index) {
-        QString tabTitle = title;
-        if (title.isEmpty())
-            tabTitle = webView->url().toString();
-        tabTitle.replace(QLatin1Char('&'), QLatin1String("&&"));
-        setTabText(index, tabTitle);
-    }
+    if (-1 == index)
+        return;
+    QString tabTitle = title;
+    if (title.isEmpty())
+        tabTitle = QString::fromUtf8(webView->url().toEncoded());
+    tabTitle.replace(QLatin1Char('&'), QLatin1String("&&"));
+    setTabText(index, tabTitle);
+    setTabToolTip(index, tabTitle);
     if (currentIndex() == index)
         emit setCurrentTitle(title);
     BrowserApplication::historyManager()->updateHistoryEntry(webView->url(), title);
@@ -742,9 +804,9 @@ void TabWidget::webViewUrlChanged(const QUrl &url)
 {
     WebView *webView = qobject_cast<WebView*>(sender());
     int index = webViewIndex(webView);
-    if (-1 != index) {
-        m_tabBar->setTabData(index, url);
-    }
+    if (-1 == index)
+        return;
+    m_tabBar->setTabData(index, url);
     emit tabsChanged();
 }
 
@@ -818,23 +880,199 @@ void TabWidget::wheelEvent(QWheelEvent *event)
 }
 #endif
 
-void TabWidget::loadUrl(const QUrl &url, Tab type, const QString &title)
+void TabWidget::retranslate()
 {
-    WebView *webView;
-    if (NewTab == type) {
-        webView = makeNewTab();
-        if (count() == 1)
-            webView = this->webView(0);
+    m_nextTabAction->setText(tr("Show Next Tab"));
+    QList<QKeySequence> shortcuts;
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_BraceRight));
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_PageDown));
+    shortcuts.append(tr("Ctrl-]"));
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_Less));
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_Tab));
+    m_nextTabAction->setShortcuts(shortcuts);
+    m_previousTabAction->setText(tr("Show Previous Tab"));
+    shortcuts.clear();
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_BraceLeft));
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_PageUp));
+    shortcuts.append(tr("Ctrl-["));
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::Key_Greater));
+    shortcuts.append(QKeySequence(Qt::CTRL | Qt::SHIFT | Qt::Key_Tab));
+    m_previousTabAction->setShortcuts(shortcuts);
+    m_recentlyClosedTabsAction->setText(tr("Recently Closed Tabs"));
+    m_newTabAction->setText(tr("New &Tab"));
+    m_closeTabAction->setText(tr("&Close Tab"));
+    m_bookmarkTabsAction->setText(tr("Bookmark All Tabs"));
+    m_tabBar->updateViewToolBarAction();
+}
+
+void TabWidget::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::LanguageChange)
+        retranslate();
+    QTabWidget::changeEvent(event);
+}
+
+/*
+    Transform string into a QUrl and then load it.
+
+    When you already have a QUrl call loadUrl()
+ */
+void TabWidget::loadString(const QString &string, OpenUrlIn tab)
+{
+    if (string.isEmpty())
+        return;
+
+    QUrl url = guessUrlFromString(string);
+    currentLineEdit()->setText(QString::fromUtf8(url.toEncoded()));
+    loadUrl(url, tab);
+}
+
+QUrl TabWidget::guessUrlFromString(const QString &string)
+{
+    QUrl url = WebView::guessUrlFromString(string);
+
+    if (url.scheme() == QLatin1String("about")
+        && url.path() == QLatin1String("home"))
+        url = QUrl(QLatin1String("qrc:/startpage.html"));
+
+    // QUrl::isValid() is too much tolerant.
+    // We actually want to check if the url conforms to the RFC, which QUrl::isValid() doesn't state.
+    if (!url.scheme().isEmpty() && (!url.host().isEmpty() || !url.path().isEmpty()))
+        return url;
+
+    QSettings settings;
+    settings.beginGroup(QLatin1String("urlloading"));
+    bool search = settings.value(QLatin1String("searchEngineFallback"), false).toBool();
+
+    if (search) {
+        url = ToolbarSearch::openSearchManager()->currentEngine()->searchUrl(string.trimmed());
     } else {
-        webView = currentWebView();
+        QString urlString = QLatin1String("http://") + string.trimmed();
+        url = QUrl::fromEncoded(urlString.toUtf8(), QUrl::TolerantMode);
     }
 
-    if (webView) {
-        webView->loadUrl(url, title);
-        webView->setFocus();
+    return url;
+}
+
+/*
+   Somewhere in the browser interface a users wants to open a url
+
+   By default open this url in the current tab, unless mouse or keyboard
+   modifiers are set.
+ */
+void TabWidget::loadUrlFromUser(const QUrl &url, const QString &title)
+{
+    loadUrl(url, modifyWithUserBehavior(CurrentTab), title);
+}
+
+void TabWidget::loadSettings()
+{
+    for (int i = 0; i < count(); ++i) {
+        WebView *v = webView(i);
+        if (v && v->page())
+            v->loadSettings();
     }
 }
 
+/*
+    Replace the openIn behavior with the behavior the user wants.
+
+    // ctrl open in new tab
+    // ctrl-shift open in new tab and select
+    // ctrl-alt open in new window
+ */
+TabWidget::OpenUrlIn TabWidget::modifyWithUserBehavior(OpenUrlIn tab) {
+    Qt::KeyboardModifiers modifiers = BrowserApplication::instance()->eventKeyboardModifiers();
+    Qt::MouseButtons buttons = BrowserApplication::instance()->eventMouseButtons();
+#ifdef USERMODIFIEDBEHAVIOR_DEBUG
+    qDebug() << __FUNCTION__ << "start" << modifiers << buttons << tab;
+#endif
+    if (modifiers & Qt::ControlModifier || buttons == Qt::MidButton) {
+        if (modifiers & Qt::AltModifier) {
+            tab = NewWindow;
+        } else {
+            QSettings settings;
+            settings.beginGroup(QLatin1String("tabs"));
+            bool select = settings.value(QLatin1String("selectNewTabs"), false).toBool();
+            if (modifiers & Qt::ShiftModifier)
+                tab = !select ? NewSelectedTab : NewNotSelectedTab;
+            else
+                tab = select ? NewSelectedTab : NewNotSelectedTab;
+        }
+    }
+#ifdef USERMODIFIEDBEHAVIOR_DEBUG
+    qDebug() << __FUNCTION__ << "end" << modifiers << buttons << tab;
+#endif
+    BrowserApplication::instance()->setEventKeyboardModifiers(0);
+    BrowserApplication::instance()->setEventMouseButtons(Qt::NoButton);
+    return tab;
+}
+
+/*
+   Somewhere in the browser interface a users wants to open a url in a specific tab.
+ */
+void TabWidget::loadUrl(const QUrl &url, OpenUrlIn tab, const QString &title)
+{
+    if (tab == UserOrCurrent) {
+        loadUrlFromUser(url, title);
+        return;
+    }
+    if (!url.isValid())
+        return;
+    WebView *webView = getView(tab, currentWebView());
+    if (webView)
+        webView->loadUrl(url, title);
+}
+
+/*
+    Return the view that matches the openIn behavior creating
+    a new view/window if necessary.
+ */
+WebView *TabWidget::getView(OpenUrlIn tab, WebView *currentView)
+{
+    WebView *webView = 0;
+    switch (tab) {
+        case NewWindow: {
+#ifdef USERMODIFIEDBEHAVIOR_DEBUG
+            qDebug() << __FUNCTION__ << "NewWindow";
+#endif
+            BrowserMainWindow *newMainWindow = BrowserApplication::instance()->newMainWindow();
+            webView = newMainWindow->currentTab();
+            webView->setFocus();
+            break;
+        }
+
+        case NewSelectedTab: {
+#ifdef USERMODIFIEDBEHAVIOR_DEBUG
+            qDebug() << __FUNCTION__ << "NewSelectedTab";
+#endif
+            webView = makeNewTab(true);
+            webView->setFocus();
+            break;
+        }
+
+        case NewNotSelectedTab: {
+#ifdef USERMODIFIEDBEHAVIOR_DEBUG
+            qDebug() << __FUNCTION__ << "NewNotSelectedTab";
+#endif
+            webView = makeNewTab(false);
+            break;
+        }
+
+        case CurrentTab:
+        default:
+#ifdef USERMODIFIEDBEHAVIOR_DEBUG
+            qDebug() << __FUNCTION__ << "CurrentTab";
+#endif
+            webView = currentView;
+            if (!webView)
+                return 0;
+            webView->setFocus();
+            break;
+    }
+    return webView;
+}
+
 void TabWidget::nextTab()
 {
     int next = currentIndex() + 1;
@@ -864,8 +1102,12 @@ QByteArray TabWidget::saveState() const
 
     QStringList tabs;
     for (int i = 0; i < count(); ++i) {
+        if (!m_swappedDelayedWidget) {
+            tabs.append(QString::null);
+            continue;
+        }
         if (WebView *tab = webView(i)) {
-            tabs.append(tab->url().toString());
+            tabs.append(QString::fromUtf8(tab->url().toEncoded()));
         } else {
             tabs.append(QString::null);
         }
@@ -892,8 +1134,10 @@ bool TabWidget::restoreState(const QByteArray &state)
 
     QStringList openTabs;
     stream >> openTabs;
-    for (int i = 0; i < openTabs.count(); ++i)
-        loadUrl(openTabs.at(i), i == 0 && currentWebView()->url() == QUrl() ? CurrentTab : NewTab);
+    for (int i = 0; i < openTabs.count(); ++i) {
+        QUrl url = QUrl::fromEncoded(openTabs.at(i).toUtf8());
+        loadUrl(url, i == 0 && currentWebView()->url() == QUrl() ? CurrentTab : NewTab);
+    }
 
     int currentTab;
     stream >> currentTab;
