@@ -122,7 +122,6 @@ void LineEdit::addWidget(QWidget *widget, WidgetPosition position)
     bool rtl = isRightToLeft();
     if (rtl)
         position = (position == LeftSide) ? RightSide : LeftSide;
-    widget->show();
     if (position == LeftSide) {
         m_leftLayout->addWidget(widget);
     } else {
@@ -193,7 +192,7 @@ void LineEdit::updateSideWidgetLocations()
     textRect.adjust(-left, 1, right, 0);
 #endif
 
-    int midHeight = textRect.center().y();
+    int midHeight = textRect.center().y() + 1;
 
     if (m_leftLayout->count() > 0) {
         int leftHeight = midHeight - m_leftWidget->height() / 2;
