@@ -66,46 +66,16 @@
 
 #include <qwebview.h>
 
-QT_BEGIN_NAMESPACE
-class QAuthenticator;
-class QMouseEvent;
-class QNetworkProxy;
-class QNetworkReply;
-class QSslError;
-QT_END_NAMESPACE
+#include "tabwidget.h"
 
-class BrowserMainWindow;
-class WebPage : public QWebPage
-{
-    Q_OBJECT
-
-signals:
-    void loadingUrl(const QUrl &url);
-
-public:
-    WebPage(QObject *parent = 0);
-    BrowserMainWindow *mainWindow();
-
-protected:
-    bool acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request, NavigationType type);
-    QWebPage *createWindow(QWebPage::WebWindowType type);
-#if !defined(QT_NO_UITOOLS)
-    QObject *createPlugin(const QString &classId, const QUrl &url, const QStringList &paramNames, const QStringList &paramValues);
+#if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+#include <qwebelement.h>
+class QLabel;
 #endif
 
-private slots:
-    void handleUnsupportedContent(QNetworkReply *reply);
-
-private:
-    friend class WebView;
-
-    // set the webview mousepressedevent
-    Qt::KeyboardModifiers m_keyboardModifiers;
-    Qt::MouseButtons m_pressedButtons;
-    bool m_openInNewTab;
-    QUrl m_loadingUrl;
-};
-
+class BrowserMainWindow;
+class TabWidget;
+class WebPage;
 class WebView : public QWebView
 {
     Q_OBJECT
@@ -114,17 +84,30 @@ public:
     WebView(QWidget *parent = 0);
     WebPage *webPage() const { return m_page; }
 
+#if !(QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK))
+    static QUrl guessUrlFromString(const QString &url);
+#endif
+    void loadSettings();
+
+#if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+    void keyReleaseEvent(QKeyEvent *event);
+#endif
+
     void loadUrl(const QUrl &url, const QString &title = QString());
-    void loadUrl(const QNetworkRequest &request, QNetworkAccessManager::Operation operation = QNetworkAccessManager::GetOperation, const QByteArray &body = QByteArray());
     QUrl url() const;
 
     QString lastStatusBarText() const;
     inline int progress() const { return m_progress; }
+    TabWidget *tabWidget() const;
+
+signals:
+    void search(const QUrl &searchUrl, TabWidget::OpenUrlIn openIn);
 
 public slots:
     void zoomIn();
     void zoomOut();
     void resetZoom();
+    void applyZoom();
 
 protected:
     void mousePressEvent(QMouseEvent *event);
@@ -132,22 +115,33 @@ protected:
     void contextMenuEvent(QContextMenuEvent *event);
     void wheelEvent(QWheelEvent *event);
     void resizeEvent(QResizeEvent *event);
+    void dragEnterEvent(QDragEnterEvent *event);
+    void dragMoveEvent(QDragMoveEvent *event);
+    void dropEvent(QDropEvent *event);
+    void keyPressEvent(QKeyEvent *event);
+
+private:
+    int levelForZoom(int zoom);
 
 private slots:
     void setProgress(int progress);
     void loadFinished();
     void setStatusBarText(const QString &string);
     void downloadRequested(const QNetworkRequest &request);
-    void openLinkInNewTab();
-    void openLinkInNewWindow();
+    void openActionUrlInNewTab();
+    void openActionUrlInNewWindow();
     void downloadLinkToDisk();
     void copyLinkToClipboard();
-    void openImageInNewTab();
     void openImageInNewWindow();
     void downloadImageToDisk();
     void copyImageToClipboard();
     void copyImageLocationToClipboard();
     void bookmarkLink();
+    void searchRequested(QAction *action);
+#if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+    void addSearchEngine();
+    void hideAccessKeys();
+#endif
 
 private:
     QString m_statusBarText;
@@ -156,6 +150,17 @@ private:
     int m_currentZoom;
     QList<int> m_zoomLevels;
     WebPage *m_page;
+
+#if QT_VERSION >= 0x040600 || defined(WEBKIT_TRUNK)
+    bool m_enableAccessKeys;
+    bool checkForAccessKey(QKeyEvent *event);
+    void showAccessKeys();
+    void makeAccessKeyLabel(const QChar &accessKey, const QWebElement &element);
+    QList<QLabel*> m_accessKeyLabels;
+    QHash<QChar, QWebElement> m_accessKeyNodes;
+    bool m_accessKeysPressed;
+#endif
 };
 
 #endif
+
